#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  File   : PyInterp.py
#  Author : Paul RASCLE, EDF
#  Module : SALOME
#  $Header: /home/server/cvs/KERNEL/KERNEL_SRC/src/KERNEL_PY/PyInterp.py,v 1.4.2.2.14.2.12.1 2012-04-12 14:05:13 vsr Exp $
#
import sys
from omniORB import CORBA
from LifeCycleCORBA import *
from libSALOME_Swig import *
import SALOMEDS
from SALOME_NamingServicePy import *

    #--------------------------------------------------------------------------

def DumpComponent(Study, SO, offset):
    it = Study.NewChildIterator(SO)
    Builder = Study.NewBuilder()
    while it.More():
        CSO = it.Value()
        it.Next()
        anAttr = Builder.FindOrCreateAttribute(CSO, "AttributeName")
        AtName = anAttr._narrow(SALOMEDS.AttributeName)
        t_name = AtName.Value()
        if t_name[0] == 1:
            ofs = 1
            a = ""
            while ofs <= offset:
                a = a + "--"
                ofs = ofs +1
            print a + ">" + CSO.GetID() + " " + t_name[1]
        t_RefSO = CSO.ReferencedObject()
        if t_RefSO[0] == 1:
            RefSO = t_RefSO[1]
            ofs = 1
            a = ""
            while ofs <= offset:
                a = a + "  "
                ofs = ofs +1
            print a + ">" + RefSO.GetID()
        DumpComponent(Study, CSO, offset+2)

    #--------------------------------------------------------------------------

def DumpStudy(Study):
    itcomp = Study.NewComponentIterator()
    while itcomp.More():
        SC = itcomp.Value()
        itcomp.Next()
        name = SC.ComponentDataType()
        print "-> ComponentDataType is " + name
        DumpComponent(Study, SC, 1)
        

    #--------------------------------------------------------------------------

# initialise the ORB
orb = CORBA.ORB_init([''], CORBA.ORB_ID)

# create an LifeCycleCORBA instance
lcc = LifeCycleCORBA(orb)

# create an SALOMEGUI_Swig instance
sg = SALOMEGUI_Swig()

#create an naming service instance
naming_service = SALOME_NamingServicePy_i(orb)

# get active study name and id
myStudyName = sg.getActiveStudyName()
print myStudyName

myStudyId = sg.getActiveStudyId()
print myStudyId

# get Study Manager reference
obj = naming_service.Resolve('myStudyManager')
myStudyManager = obj._narrow(SALOMEDS.StudyManager)

# get active study
myStudy = myStudyManager.GetStudyByName(myStudyName)



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

import unittest
import salome
import Engines
import LifeCycleCORBA
salome.salome_init()
cm= salome.lcc.getContainerManager()
rm= salome.lcc.getResourcesManager()

class TestContainerManager(unittest.TestCase):
  """
Test with catalog :
<!DOCTYPE ResourcesCatalog>
<resources>
   <machine hostname="claui2c6" >
   </machine>
   <machine hostname="clt10br" >
   </machine>
</resources>
"""
  def setUp(self):
    pass

  def test0(self):
    """"""
    rp=LifeCycleCORBA.ResourceParameters(policy="best",componentList=["PYHELLO"])
    p=LifeCycleCORBA.ContainerParameters(container_name="MyContainer",mode="start",resource_params=rp)
    co=cm.GiveContainer( p )
    self.assertEqual(co._get_name(), "/Containers/claui2c6/MyContainer")
    co=cm.GiveContainer( p )
    self.assertEqual(co._get_name(), "/Containers/clt10br/MyContainer")

  def test1(self):
    """"""
    rp=LifeCycleCORBA.ResourceParameters(policy="best",componentList=["PYHELLO"])
    p=LifeCycleCORBA.ContainerParameters(container_name="MyContainer",mode="get",resource_params=rp)
    co=cm.GiveContainer( p )
    self.assertEqual(co._get_name(), "/Containers/claui2c6/MyContainer")
    co=cm.GiveContainer( p )
    self.assertEqual(co._get_name(), "/Containers/clt10br/MyContainer")

  def test2(self):
    """"""
    rp=LifeCycleCORBA.ResourceParameters(policy="best",componentList=["PYHELLO"])
    p=LifeCycleCORBA.ContainerParameters(container_name="MyContainer",mode="getorstart",resource_params=rp)
    co=cm.GiveContainer( p )
    self.assertEqual(co._get_name(), "/Containers/claui2c6/MyContainer")
    co=cm.GiveContainer( p )
    self.assertEqual(co._get_name(), "/Containers/clt10br/MyContainer")


if __name__ == '__main__':
  suite = unittest.TestLoader().loadTestsFromTestCase(TestContainerManager)
  unittest.TextTestRunner().run(suite)




#! /usr/bin/env python
#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  SALOME TestContainer : test of container creation and its life cycle
#  File   : SALOME_TestComponentPy.py
#  Author : Paul RASCLE, EDF
#  Module : SALOME
#  $Header: /home/server/cvs/KERNEL/KERNEL_SRC/src/TestContainer/SALOME_TestComponentPy.py,v 1.6.2.1.14.2.12.1 2012-04-12 14:05:31 vsr Exp $
#
import sys
from omniORB import CORBA, PortableServer
import CosNaming
import Engines, Engines__POA
from SALOME_ComponentPy import *

class SALOME_TestComponentPy( Engines__POA.TestComponent, SALOME_ComponentPy_i):

    def Coucou(self, val):
        print "SALOME_TestComponentPy Coucou ", val
        result = "result from SALOME_TestComponentPy Coucou " + `val`
        return result
    
    def __init__(self, orb, poa, contID, containerName, instanceName, interfaceName):
        notif = 0
        SALOME_ComponentPy_i.__init__(self, orb, poa, contID, containerName,
                                      instanceName, interfaceName, notif)
        print "SALOME_TestComponentPy::__init__"




#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  File   : salome_version.py
#  Author : Vadim SANDLER
#  Module : SALOME
#
__ALL__ = [
    "getVersion",
    "getVersionMajor",
    "getVersionMinor",
    "getVersionRelease",
    "getVersions",
    "getXVersion",
    "isDevelopmentVersion",
    ]

_salome_versions = {}

def getVersion( mod = "KERNEL", full = False ):
    """
    Get SALOME module version number
    Parameters:
    - mod  : SALOME module name, default is 'KERNEL'
    - full : take into account development marker (in this case 'dev' is added
             to the end of version value for development version), False by default
    Returns: version number string or None if VERSION file is not found
    """
    global _salome_versions
    mod = mod.upper()
    dev_flag = { True : "dev", False : "" }
    if not _salome_versions.has_key( mod ):
        _salome_versions[ mod ] = [ None, "" ]
        import os
        root_dir = os.getenv( "%s_ROOT_DIR" % mod )
        if root_dir:
            try:
                filename = root_dir + "/bin/salome/VERSION"
                if not os.path.exists( filename ):
                    filename = root_dir + "/bin/VERSION"
                f = open( filename )
                data = f.readlines()
                f.close()
                for l in data:
                    if l.strip().startswith("#") or ":" not in l: continue
                    key = ":".join( l.split( ":" )[ :-1 ] ).strip()
                    val = l.split( ":" )[ -1 ].strip()
                    if "development" in key.lower():
                        _salome_versions[ mod ][ 1 ] = dev_flag[ val == "1" ]
                    elif "version" in key.lower() or mod in key:
                        _salome_versions[ mod ][ 0 ] = val
                    pass
            except:
                pass
    v = _salome_versions[ mod ][ 0 ]
    if full and v is not None:
        v += _salome_versions[ mod ][ 1 ]
    return v

def getVersionMajor( mod = "KERNEL" ):
    """
    Get SALOME module major version number
    Parameters:
    - mod  : SALOME module name, default is 'KERNEL'
    Returns: version major number string or None if VERSION file is not found
    """
    ver = getVersion( mod )
    try:
        return ver.split( "." )[ 0 ]
    except:
        pass
    return None

def getVersionMinor( mod = "KERNEL" ):
    """
    Get SALOME module minor version number
    Parameters:
    - mod  : SALOME module name, default is 'KERNEL'
    Returns: version minor number string or None if VERSION file is not found
    """
    ver = getVersion( mod )
    try:
        return ver.split( "." )[ 1 ]
    except:
        pass
    return None

def getVersionRelease( mod = "KERNEL" ):
    """
    Get SALOME module release version number
    Parameters:
    - mod  : SALOME module name, default is 'KERNEL'
    Returns: version release number string or None if VERSION file is not found
    """
    ver = getVersion( mod )
    try:
        return ver.split( "." )[ 2 ]
    except:
        pass
    return None

def getVersions( mod = "KERNEL" ):
    """
    Get SALOME module version as list of [major, minor, release] numbers
    Parameters:
    - mod  : SALOME module name, default is 'KERNEL'
    Returns: version numbers list
    """
    try:
        major = int( getVersionMajor( mod ) )
    except:
        major = 0
        pass
    try:
        minor = int( getVersionMinor( mod ) )
    except:
        minor = 0
        pass
    try:
        rel = int( getVersionRelease( mod ) )
    except:
        rel = 0
        pass
    return [ major, minor, rel ]
    
def getXVersion( mod = "KERNEL" ):
    """
    Get SALOME module version as list of [major, minor, release] numbers
    Parameters:
    - mod  : SALOME module name, default is 'KERNEL'
    Returns: version numbers list
    """
    major, minor, rel = getVersions( mod )
    return hex( (major<<16) + (minor<<8) + rel )

def isDevelopmentVersion( mod = "KERNEL" ):
    """
    Checks if the version of SALOME module is marked as development one
    Parameters:
    - mod  : SALOME module name, default is 'KERNEL'
    Returns: Return True for delopment version of module or False otherwise
    """
    ver = getVersion( mod, True )
    return ver.endswith( "dev" )



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  File   : salome.py renamed as __init__.py for python packaging (gboulant)
#  Author : Paul RASCLE, EDF
#  Module : SALOME
#
""" 
Module salome gives access to Salome ressources.

variables:

  - salome.orb             : CORBA
  - salome.naming_service  : instance of naming Service class
      - methods:
          - Resolve(name)  : find a CORBA object (ior) by its pathname
          - Register(name) : register a CORBA object under a pathname

  - salome.lcc             : instance of lifeCycleCORBA class
      - methods:
          - FindOrLoadComponent(server,name) :
                           obtain an Engine (CORBA object)
                           or launch the Engine if not found,
                           with a Server name and an Engine name

  - salome.sg              : salome object to communicate with the graphical user interface (if any)
      - methods:
         - updateObjBrowser(bool):
         - getActiveStudyId():
         - getActiveStudyName():

         - SelectedCount():      returns number of selected objects
         - getSelected(i):       returns entry of selected object number i
         - getAllSelected():     returns list of entry of selected objects
         - AddIObject(Entry):    select an existing Interactive object
         - RemoveIObject(Entry): remove object from selection
         - ClearIObjects():      clear selection

         - Display(*Entry):
         - DisplayOnly(Entry):
         - Erase(Entry):
         - DisplayAll():
         - EraseAll():

         - IDToObject(Entry):    returns CORBA reference from entry

  - salome.myStudyName     : active Study Name
  - salome.myStudyId       : active Study Id
  - salome.myStudy         : the active Study itself (CORBA ior)
      - methods : defined in SALOMEDS.idl

"""
## @package salome
# Module salome gives access to Salome ressources.
#
#  \param salome.orb             : CORBA orb object
#  \param salome.naming_service  : instance of naming Service class (SALOME_NamingServicePy::SALOME_NamingServicePy_i)
#  \param salome.lcc             : instance of lifeCycleCORBA class (SALOME_LifeCycleCORBA)
#  \param salome.sg              : Salome object to communicate with the graphical user interface, if running (see interface in salome_iapp::SalomeOutsideGUI)
#  \param salome.myStudyName     : active Study Name
#  \param salome.myStudyId       : active Study Id
#  \param salome.myStudy         : the active Study (interface SALOMEDS::Study)

#
# ==========================================================================
#
# The function extend_path is used here to aggregate in a single
# virtual python package all the python sub-packages embedded in each
# SALOME modules (python "namespace" pattern).
#
ROOT_PYTHONPACKAGE_NAME="salome"
#
# This root package name is expected to be found as a directory in
# some paths of the sys.path variable, especially the paths
# <MODULE_ROOT_DIR>/lib/pythonX.Y/site-packages/salome where are
# installed the python files. These paths are theorically appended by
# the SALOME main runner and should be in the sys.path at this point
# of the application. The extend_path is looking then for directories
# of the type:
#
# <MODULE_ROOT_DIR>/lib/pythonX.Y/site-packages/salome/<ROOT_PYTHONPACKAGE_NAME>
#
# And append them to the sys.path. These directories are supposed to
# be the pieces to be aggregated as a single virtual python package.
#
import os, sys
from salome_utils import verbose

MATCH_ENDING_PATTERN="site-packages" + os.path.sep + "salome"

def extend_path(pname):
    for dir in sys.path:
        if not isinstance(dir, basestring) or not os.path.isdir(dir) or not dir.endswith(MATCH_ENDING_PATTERN):
            continue
        subdir = os.path.join(dir, pname)
        # XXX This may still add duplicate entries to path on
        # case-insensitive filesystems
        if os.path.isdir(subdir) and subdir not in __path__:
            if verbose(): print "INFO - The directory %s is appended to sys.path" % subdir
            __path__.append(subdir)

extend_path(ROOT_PYTHONPACKAGE_NAME)
# ==========================================================================
#

from salome_kernel import *
from salome_study import *
from salome_iapp import *
import salome_study

#
# The next block is workaround for the problem of shared symbols loading for the extension modules (e.g. SWIG-generated)
# that causes RTTI unavailable in some cases. To solve this problem, sys.setdlopenflags() function is used.
# Depending on the Python version and platform, the dlopen flags can be defined in the dl, DLFUN or ctypes module.
# 
import sys
flags = None
if not flags:
    try:
        # dl module can be unavailable
        import dl
        flags = dl.RTLD_NOW | dl.RTLD_GLOBAL
    except:
        pass
    pass
if not flags:
    try:
        # DLFCN module can be unavailable
        import DLFCN
        flags = DLFCN.RTLD_NOW | DLFCN.RTLD_GLOBAL
    except:
        pass
    pass
if not flags:
    try:
        # ctypes module can be unavailable
        import ctypes
        flags = ctypes.RTLD_GLOBAL
    except:
        pass
    pass

# Disable -> bug with scipy, seems very dangerous to do that
#if flags:
#    sys.setdlopenflags(flags)
#    pass

orb, lcc, naming_service, cm,sg=None,None,None,None,None
myStudyManager, myStudyId, myStudy, myStudyName=None,None,None,None

def setCurrentStudy(theStudy):
    """
    Change current study : an existing one given by a study object.

    :param theStudy: the study CORBA object to set as current study
    """
    global myStudyId, myStudy, myStudyName
    myStudyId, myStudy, myStudyName =salome_study.setCurrentStudy(theStudy)

def setCurrentStudyId(theStudyId=0):
    """
    Change current study : an existing or new one given by Id.

    :param theStudyId: the study Id (optional argument)
           0      : create a new study (default).
           n (>0) : try connection to study with Id = n, or create a new one
                      if study not found.
    """
    global myStudyId, myStudy, myStudyName
    myStudyId, myStudy, myStudyName =salome_study.setCurrentStudyId(theStudyId)

salome_initial=1
def salome_init(theStudyId=0,embedded=0):
    """
    Performs only once SALOME general purpose intialisation for scripts.
    optional argument : theStudyId
      When in embedded interpreter inside IAPP, theStudyId is not used
      When used without GUI (external interpreter)
        0      : create a new study (default).
        n (>0) : try connection to study with Id = n, or create a new one
                 if study not found.
                 If study creation, its Id may be different from theStudyId !
    Provides:
    orb             reference to CORBA
    lcc             a LifeCycleCorba instance
    naming_service  a naming service instance
    cm              reference to the container manager
    sg              access to SALOME GUI (when linked with IAPP GUI)
    myStudyManager  the study manager
    myStudyId       active study identifier
    myStudy         active study itself (CORBA reference)
    myStudyName     active study name
    """
    global salome_initial
    global orb, lcc, naming_service, cm
    global sg
    global myStudyManager, myStudyId, myStudy, myStudyName

    try:
        if salome_initial:
            salome_initial=0
            sg = salome_iapp_init(embedded)
            orb, lcc, naming_service, cm = salome_kernel_init()
            myStudyManager, myStudyId, myStudy, myStudyName =salome_study_init(theStudyId)
            pass
        pass
    except RuntimeError, inst:
        # wait a little to avoid trace mix
        import time
        time.sleep(0.2)
        x = inst
        print "salome.salome_init():", x
        print """
        ============================================
        May be there is no running SALOME session
        salome.salome_init() is intented to be used
        within an already running session
        ============================================
        """
        raise

#to expose all objects to pydoc
__all__=dir()



#! /usr/bin/env python
#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

import socket
import os
import sys
import shutil

#####################################################################
def findFreePort(startPort, step) :

    currentPort = startPort;
    if step < 1:
        step = 1;

    serversocket = socket.socket(socket.AF_INET, socket.SOCK_STREAM);

    portFound = 0;
    while (portFound != 1 and currentPort < 65536):
        try :
            serversocket.bind((socket.gethostname(), currentPort));
            portFound = 1;
            print str(currentPort) + ": " + "OK";
#            serversocket.shutdown(0);
#            serversocket.close();
        except Exception, inst:
            print str(currentPort) + ": " + str(inst.args);
            currentPort = currentPort+step;
    
    
    
    
    if (portFound != 1) :
        currentPort = -1;
    return currentPort;
#####################################################################



## 1. Generate config file for omniORB:
# content:
# InitRef = NameService=corbaname::[HOST_NAME]:[PORT_NUMBER]

freePort = findFreePort(2810, 1);
hostName = socket.gethostname();

if (len(sys.argv) > 1) and sys.argv[1] == "-nothing" :
    print "port:" + str(freePort);
    sys.exit(0)
    

        

if freePort < 0 :
    print
    print "Can't find a free port to launch omniNames"
    print "Try to kill the running servers and then launch SALOME again."
    print
    sys.exit(0)
    
else :
    omniCfgFileContent = "InitRef = NameService=corbaname::" + str(hostName) + ":" + str(freePort);
    omniCfgFilePath = os.environ.get('HOME') + "/" + ".omniORB_" + str(hostName) + "_" + str(freePort) + ".cfg";

    omni_file = file(omniCfgFilePath,'w+');
    omni_file.write(omniCfgFileContent);
    omni_file.write("\n");
    omni_file.close();

    if (len(sys.argv) > 1) and sys.argv[1] == "--save-config" :
        omniCfgCurrent = os.environ.get('HOME') + "/.omniORB_current.cfg";
        if os.name == "posix" :
            #make a symbolic link
            symlink(omniCfgFilePath, omniCfgCurrent);
        else :
            #copy the file
            shutil.copy(omniCfgFilePath, omniCfgCurrent);
            
        omniCfgFilePath = omniCfgCurrent;
            
    
    

    ## 2. Set the OMNIORB_CONFIG environment variable
    os.environ['OMNIORB_CONFIG']=omniCfgFilePath;


    ## 3. execute the file runSalome.py
    runSalomePyFilePath = os.environ.get('KERNEL_ROOT_DIR') + "/bin/salome/runSalome.py";

    if os.path.isfile(runSalomePyFilePath) :
        execfile(runSalomePyFilePath);
        



#!/usr/bin/env python
#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

import sys, os, re, socket
#import commands
from server import *
from Utils_Identity import getShortHostName
from launchConfigureParser import verbose

# -----------------------------------------------------------------------------

class NamingServer(Server):
   XTERM=""
   USER=os.getenv('USER')
   if USER is None:
      USER='anonymous'
   #os.system("mkdir -m 777 -p /tmp/logs")
   LOGDIR="/tmp/logs/" + USER

   def initNSArgs(self):
        if sys.platform == "win32":
          # temporarily using home directory for Namning Service logs
          # to be replaced with TEMP later...
          os.environ["BaseDir"]=os.environ["HOME"]
        else:
          os.environ["BaseDir"]="/tmp"

        try:
          os.mkdir(os.environ["BaseDir"] + "/logs")
          os.chmod(os.environ["BaseDir"] + "/logs", 0777)
        except:
          #print "Can't create " + os.environ["BaseDir"] + "/logs"
          pass

        upath = os.environ["BaseDir"] + "/logs/";
        if sys.platform == "win32":
           upath += os.environ["Username"];
        else:
           upath += os.environ["USER"];

        try:
          os.mkdir(upath)
        except:
          #print "Can't create " + upath
          pass

        if verbose(): print "Name Service... ",
        #hname=os.environ["HOST"] #commands.getoutput("hostname")
        if sys.platform == "win32":
          hname=getShortHostName();
        else:
          hname = socket.gethostname();
        #print "hname=",hname

        f=open(os.environ["OMNIORB_CONFIG"])
        ss=re.findall("NameService=corbaname::" + hname + ":\d+", f.read())
        if verbose(): print "ss = ", ss,
        f.close()
        sl=ss[0]
        ll = sl.split(':')
        aPort = ll[-1]
        #aPort=(ss.join().split(':'))[2];
        #aPort=re.findall("\d+", ss[0])[0]

        # \begin{E.A.}
        # put the log files of omniNames in different directory with port reference,
        # it is cleaner on linux and it is a fix for salome since it is impossible to
        # remove the log files if the corresponding omniNames has not been killed.
        # \end{E.A.}
        
        upath += "/omniNames_%s"%(aPort)
        try:
           os.mkdir(upath)
        except:
           #print "Can't create " + upath
           pass
        
        #os.system("touch " + upath + "/dummy")
        for fname in os.listdir(upath):
          try:
             os.remove(upath + "/" + fname)
          except:
            pass
        #os.system("rm -f " + upath + "/omninames* " + upath + "/dummy " + upath + "/*.log")

        #aSedCommand="s/.*NameService=corbaname::" + hname + ":\([[:digit:]]*\)/\1/"
        #print "sed command = ", aSedCommand
        #aPort = commands.getoutput("sed -e\"" + aSedCommand + "\"" + os.environ["OMNIORB_CONFIG"])
        #print "port=", aPort
        if sys.platform == "win32":
          #print "start omniNames -start " + aPort + " -logdir " + upath
          self.CMD=['omniNames -start ' , aPort , ' -nohostname ', ' -logdir ' , '\"' + upath + '\"', ' -errlog', '\"' + upath+'/omniNameErrors.log' + '\"']
          #os.system("start omniNames -start " + aPort + " -logdir " + upath)
        else:
          #self.CMD=['omniNames -start ' , aPort , ' -logdir ' , upath , ' &']
          self.CMD=['omniNames','-start' , aPort, '-logdir' , upath, '-errlog', upath+'/omniNameErrors.log']
          #os.system("omniNames -start " + aPort + " -logdir " + upath + " &")

        if verbose(): print "... ok"
        if verbose(): print "to list contexts and objects bound into the context with the specified name : showNS "


   def initArgs(self):
        Server.initArgs(self)
        if sys.platform == "win32":
          env_ld_library_path=['env', 'LD_LIBRARY_PATH=' + os.getenv("PATH")]
        else:
          env_ld_library_path=['env', 'LD_LIBRARY_PATH=' + os.getenv("LD_LIBRARY_PATH")]
        self.CMD=['xterm', '-e']+ env_ld_library_path + ['python']
        self.initNSArgs()

# In LifeCycleCORBA, FactoryServer is started with rsh on the requested
#    computer if this Container does not exist. Default is localhost.
#    Others Containers are started with start_impl method of FactoryServer Container.
# For using rsh it is necessary to have in the ${HOME} directory a .rhosts file
# Warning : on RedHat the file /etc/hosts contains by default a line like :
# 127.0.0.1               bordolex bordolex.paris1.matra-dtv.fr localhost.localdomain localhost  
#   (bordolex is the station name). omniNames on bordolex will be accessible from other
#   computers only if the computer name is removed on that line like :
#   127.0.0.1               bordolex.paris1.matra-dtv.fr localhost.localdomain localhost

# To start dynamically Containers on several computers you need to
# put in the ${OMNIORB_CONFIG} file a computer name instead of "localhost"
# example : ORBInitRef NameService=corbaname::dm2s0017

# If you need to use several omniNames running on the same computer, you have to :
#1. put in your ${OMNIORB_CONFIG} file a computer name and port number
# example : ORBInitRef NameService=corbaname::dm2s0017:1515
#2. start omninames with this port number like in orbmodile.py
# example : omniNames -start 1515 -logdir ${BaseDir}/logs/${Username} &



# Copyright (C) 2011-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

"""
This module provides classes and functions to handle "Exchange Variables",
i.e. description of variables to be exchanged between a supervision code and a
computation code. These Exchange Variables can be stored in a SObject in
Salome study.
"""

from xml.dom.minidom import getDOMImplementation, parse
from salome.kernel.studyedit import getStudyEditor

DEFAULT_NAME = "Variables"
INPUT_VAR_NAMES = "ExchangeVariables.InputVarNames"
OUTPUT_VAR_NAMES = "ExchangeVariables.OutputVarNames"
REF_ENTRY = "ExchangeVariables.RefEntry"

class Variable:
    """
    This class describes a single variable. For now, it is only described by
    its name. Other attributes are reserved for future use.
    """
    
    def __init__(self, name, dimension = [], minValue = None, maxValue = None,
                 initialValue = None):
        self.name = name
        
        # Reserved for future use
        self.dimension = dimension
        self.minValue = minValue
        self.maxValue = maxValue
        self.initialValue = initialValue


class ExchangeVariables:
    """
    This class describes "Exchange Variables", i.e. a structure containing all
    the necessary information to exchange variables between a supervision code
    and a computation code.

    .. attribute:: inputVarList
    
       This instance attribute is a list of :class:`Variable` objects,
       describing the input variables for the computation code.

    .. attribute:: outputVarList
    
       This instance attribute is a list of :class:`Variable` objects,
       describing the output variables for the computation code.

    .. attribute:: refEntry

       This instance attribute is optional and can be used to store a
       reference to a Salome entry containing an "Exchange Variable" SObject
       that was used to build this one (when the current object has been built
       by selecting variables of interest in a list of potential variables).

    """
    
    def __init__(self, inputVarList = [], outputVarList = [],
                 refEntry = None):
        self.inputVarList = inputVarList
        self.outputVarList = outputVarList
        self.refEntry = refEntry

    def saveToXmlFile(self, filepath):
        """
        Save this object to an XML file.
    
        :type  filepath: string
        :param filepath: path of the XML file.
    
        """
        doc = getDOMImplementation().createDocument(None, "variables", None)
        top_el = doc.documentElement
        top_el.setAttribute("version", "6.4")
        input_variables_el = doc.createElement("input_variables")
        top_el.appendChild(input_variables_el)
        output_variables_el = doc.createElement("output_variables")
        top_el.appendChild(output_variables_el)
        for input_var in self.inputVarList:
            input_var_el = doc.createElement("variable")
            input_var_el.setAttribute("name", input_var.name)
            input_variables_el.appendChild(input_var_el)
        for output_var in self.outputVarList:
            output_var_el = doc.createElement("variable")
            output_var_el.setAttribute("name", output_var.name)
            output_variables_el.appendChild(output_var_el)
        f = open(filepath, "w")
        f.write(doc.toprettyxml(indent = "  "))
        f.close()

def createSObjectForExchangeVariables(fatherSobj, exchangeVariables,
                                      name = DEFAULT_NAME,
                                      icon = None, typeId = None):
    """
    Create a SObject to store an :class:`ExchangeVariables` instance.

    :type  fatherSobj: SObject
    :param fatherSobj: parent of the SObject to create.

    :type  exchangeVariables: :class:`ExchangeVariables`
    :param exchangeVariables: :class:`ExchangeVariables` instance to store in
                              Salome study.

    :type  name: string
    :param name: name of the SObject to create.

    :type  icon: string
    :param icon: icon of the SObject to create.

    :type  typeId: integer
    :param typeId: type of the SObject to create.

    :return: the newly created SObject.

    """
    studyId = fatherSobj.GetStudy()._get_StudyId()
    editor = getStudyEditor(studyId)
    sobj = editor.createItem(fatherSobj,
                             name = name,
                             icon = icon,
                             typeId = typeId)
    _setSObjectForExchangeVariables(editor, sobj, exchangeVariables)

def updateSObjectForExchangeVariables(sobj, exchangeVariables,
                                      name = DEFAULT_NAME,
                                      icon = None, typeId = None):
    """
    Update an existing SObject storing an :class:`ExchangeVariables` instance.

    :type  sobj: SObject
    :param sobj: the SObject to update.

    See :func:`createSObjectForExchangeVariables` for the description of the
    other parameters.

    """
    studyId = sobj.GetStudy()._get_StudyId()
    editor = getStudyEditor(studyId)
    editor.setItem(sobj, name = name, icon = icon, typeId = typeId)
    editor.builder.RemoveAttribute(sobj, "AttributeParameter")
    _setSObjectForExchangeVariables(editor, sobj, exchangeVariables)

def _setSObjectForExchangeVariables(editor, sobj, exchangeVariables):
    attr = editor.builder.FindOrCreateAttribute(sobj, "AttributeParameter")
    attr.SetStrArray(INPUT_VAR_NAMES,
                     [x.name for x in exchangeVariables.inputVarList])
    attr.SetStrArray(OUTPUT_VAR_NAMES,
                     [x.name for x in exchangeVariables.outputVarList])
    if exchangeVariables.refEntry is not None:
        attr.SetString(REF_ENTRY, exchangeVariables.refEntry)

def getExchangeVariablesFromSObject(sobj):
    """
    Get an :class:`ExchangeVariables` instance from a SObject that stores it.

    :type  sobj: SObject
    :param sobj: the SObject from which to read the :class:`ExchangeVariables`
                 instance.

    :return: the newly created :class:`ExchangeVariables` instance.

    """
    (found, attr) = sobj.FindAttribute("AttributeParameter")
    if not found:
        return None
    refEntry = None
    if attr.IsSet(REF_ENTRY, 3):
        refEntry = attr.GetString(REF_ENTRY)
    return ExchangeVariables(
            [Variable(name) for name in attr.GetStrArray(INPUT_VAR_NAMES)],
            [Variable(name) for name in attr.GetStrArray(OUTPUT_VAR_NAMES)],
            refEntry)

def loadExchangeVariablesFromXmlFile(filepath):
    """
    Load an :class:`ExchangeVariables` instance from an XML file.

    :type  filepath: string
    :param filepath: path of the XML file to load.

    :return: the newly created :class:`ExchangeVariables` instance.

    """
    doc = parse(filepath)
    top_el = doc.documentElement
    # Check version
    version = top_el.getAttribute("version")
    if version != "6.4":
        raise Exception(self.tr("Unsupported version: %s" % version))
    input_variables_el = top_el.getElementsByTagName("input_variables")[0]
    input_var_list = [Variable(input_var_el.getAttribute("name"))
                      for input_var_el
                      in input_variables_el.getElementsByTagName("variable")]
    output_variables_el = top_el.getElementsByTagName("output_variables")[0]
    output_var_list = [Variable(output_var_el.getAttribute("name"))
                       for output_var_el
                       in output_variables_el.getElementsByTagName("variable")]
    return ExchangeVariables(input_var_list, output_var_list)



#!/usr/bin/env python
#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

import os

def relpath(target, base):
    """ Find relative path from base to target
        if target== "/local/chris/appli" and base== "/local/chris" the result is appli
        if target== /tmp/appli and base /local/chris the result is ../../tmp/appli
    """
    target=target.split(os.path.sep)
    base=base.split(os.path.sep)
    for i in xrange(len(base)):
      if base[i] != target[i]:
        i=i-1
        #not in base
        break
    p=['..']*(len(base)-i-1)+target[i+1:]
    if p == []:
      return '.'
    return os.path.join( *p )

def set_var(VAR, strpath):
    """Set VAR environment variable """
    value = "%r" % strpath
    shell = os.getenv('SHELL')
    if shell and shell.endswith('csh'):
        return "setenv %s %s" % (VAR, value)
    else:
        return "export %s=%s" % (VAR, value)

if __name__ == "__main__":
  applipath=relpath(os.path.realpath(os.path.dirname(__file__)),os.path.realpath(os.getenv('HOME')))
  print applipath



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

import salome
import string
import SALOME
import SALOMEDS
import SALOME_Session_idl

PT_INTEGER = 0
PT_REAL = 1
PT_BOOLEAN = 2
PT_STRING = 3
PT_REALARRAY = 4
PT_INTARRAY = 5
PT_STRARRAY = 6

_AP_LISTS_LIST_ = "AP_LISTS_LIST"
_AP_ENTRIES_LIST_ = "AP_ENTRIES_LIST"
_AP_PROPERTIES_LIST_ = "AP_PROPERTIES_LIST"
_AP_DUMP_PYTHON_ = "AP_DUMP_PYTHON"

vp_session = None

def getSession():
    global vp_session
    if vp_session is None:
        vp_session = salome.naming_service.Resolve("/Kernel/Session")
        vp_session = vp_session._narrow(SALOME.Session)
        pass
    return vp_session 

class IParameters:
    """
    Interface IParameters was designed to provide a common way to set up
    named parameters. The interface is initialized by AttributeParameter that
    is used as a container of stored data.
    The interface supports 3 types of named parameters:
    1. Named list - a named list consists of string values.
       One can append value to list (method 'append'), get a number of values
       in the list (method 'nbValues'), get all values of the given list
       (method 'getValues') and get names of all created named lists.
    2. Parameters - that is a set of named string values associated with some named
       entity. Parameter consists of tree elements: entity name, a parameter name
       and a parameter value. Thus for one named entity there are an arbitrary number
       of pair 'name parameter : value'.
       One can add a new parameter to entry (method 'setParameter'), get a value of
       a given named parameter of the given entry (method 'getParameter'), get a number
       of parameters of the given entry (method 'getNbParameters'), get all names of
       parameters for the given entry (method 'getAllParameterNames'), get all
       values of parameters for the entry (method 'getAllParameterValues') and get all
       stored entries (method 'getEntries')
    3. Property - a property has a name and a string value.
       One can set property (method 'setProperty'), getProperty (method 'getProperty') and
       get a list of all stored properties (method 'getProperties').

    Note:   
          Methods not mentioned above are private and is not supposed to be used
          by module's developers.
       
    """
    def __init__(self, attributeParameter, clr=False):
        """Initializes the instance. If clr parameter is True, all IAPP attribute values are cleared."""
        self._ap = attributeParameter
        if ( clr ): self.clear()
        pass
	
    def clear(self):
        """Clear parameters"""
	self._ap.Clear()

    def append(self, listName, value):
        """Appends a value to the named list"""
        if self._ap is None: return -1
        v = []
        if self._ap.IsSet(listName, PT_STRARRAY) == 0:
            if self._ap.IsSet(_AP_LISTS_LIST_, PT_STRARRAY) == 0: self._ap.SetStrArray(_AP_LISTS_LIST_, v);
            if listName != _AP_ENTRIES_LIST_ and listName != _AP_PROPERTIES_LIST_:
                self.append(_AP_LISTS_LIST_, listName)
                pass
            self._ap.SetStrArray(listName, v)
            pass
        
        v = self._ap.GetStrArray(listName)
        v.append(value)
        self._ap.SetStrArray(listName, v)
        return (len(v)-1)
    
    def nbValues(self, listName):
        """Returns a number of values in the named list"""
        if self._ap is None: return -1
        if self._ap.IsSet(listName, PT_STRARRAY) == 0: return 0
        v = self._ap.GetStrArray(listName)
        return len(v)

    def getValues(self, listName):
        """Returns a list of values in the named list"""
        v = []
        if self._ap is None: return v
        if self._ap.IsSet(listName, PT_STRARRAY) == 0: return v
        return self._ap.GetStrArray(listName)

    def getLists(self):
        """Returns a list of named lists' names"""
        v = []
        if self._ap is None: return v
        if self._ap.IsSet(_AP_LISTS_LIST_, PT_STRARRAY) == 0: return v
        return self._ap.GetStrArray(_AP_LISTS_LIST_)

    def setParameter(self, entry, parameterName, value):
        """Sets a value of the named parameter for the entry"""
        if self._ap is None: return
        v = []
        if self._ap.IsSet(entry, PT_STRARRAY) ==0: 
            self.append(_AP_ENTRIES_LIST_, entry) #Add the entry to the internal list of entries
            self._ap.SetStrArray(entry, v)
            pass
        
        v = self._ap.GetStrArray(entry)
        v.append(parameterName)
        v.append(value)
        self._ap.SetStrArray(entry, v)
        pass

    def getParameter(self, entry, parameterName):
        """Returns a value of the named parameter for the entry"""
        if self._ap is None: return ""
        if self._ap.IsSet(entry, PT_STRARRAY) == 0: return ""
        v = self._ap.GetStrArray(entry)
        length = len(v);
        i = 0
        while i<length:
            if v[i] == parameterName: return v[i+1]
            i+=1
            pass
        
        return ""

    def getAllParameterNames(self, entry):
        """Returns all parameter names of the given entry"""
        v = []
        names = []
        if self._ap is None: return v
        if self._ap.IsSet(entry, PT_STRARRAY) == 0: return v
        v = self._ap.GetStrArray(entry)
        length = len(v)
        i = 0
        while i<length:
            names.append(v[i])
            i+=2
            pass
        
        return names

    def getAllParameterValues(self, entry):
        """Returns all parameter values of the given entry"""
        v = []
        values = []
        if self._ap is None: return v
        if self._ap.IsSet(entry, PT_STRARRAY) == 0: return v
        v = self._ap.GetStrArray(entry)
        length = len(v)
        i = 1
        while i<length:
            values.append(v[i]+1)
            i+=2
            pass
        
        return values

    def getNbParameters(self, entry):
        """Returns a number of parameters of the entry"""
        if self._ap is None: return -1
        if self._ap.IsSet(entry, PT_STRARRAY) == 0: return -1
        return len(self._ap.GetStrArray(entry))/2

    def getEntries(self):
        """Returns all entries"""
        v = []
        if self._ap is None: return v
        if self._ap.IsSet(_AP_ENTRIES_LIST_, PT_STRARRAY) == 0: return v
        return self._ap.GetStrArray(_AP_ENTRIES_LIST_)

    def setProperty(self, name, value):
        """Sets a property value"""
        if self._ap is None: return
        if self._ap.IsSet(name, PT_STRING) == 0: 
            self.append(_AP_PROPERTIES_LIST_, name) #Add the property to the internal list of properties
            pass
        self._ap.SetString(name, value)
        pass

    def getProperty(self, name):
        """Returns a value of the named property"""
        if self._ap is None: return ""
        if self._ap.IsSet(name, PT_STRING) == 0: return ""
        return self._ap.GetString(name)

    def getProperties(self):
        """Returns all propetries"""
        v = []
        if self._ap is None: return v
        if self._ap.IsSet(_AP_PROPERTIES_LIST_, PT_STRARRAY) == 0: return v
        return self._ap.GetStrArray(_AP_PROPERTIES_LIST_)

    def parseValue(self, value, separator, fromEnd):
        """Breaks a value string in two parts which is divided by separator."""
        v = []
        pos = - 1
        if fromEnd == 1: pos = value.rfind(separator)
        else: pos = value.find(separator)

        if pos < 0: 
            v.append(value)
            return v
        
        part1 = value[0:pos]
        part2 = value[pos+1:len(value)]
        v.append(part1)
        v.append(part2)
        return v

    def setDumpPython(self, isDumping):
        """Enables/Disables the dumping to Python"""
        if self._ap is None: return
        _ap.SetBool(_AP_DUMP_PYTHON_, isDumping)
        pass

    def isDumpPython(self):
        """Returns whether there is the dumping to Python"""
        if self._ap is None: return 0
        if self._ap.IsSet(_AP_DUMP_PYTHON_, PT_BOOLEAN) == 0: return 0
        return self._ap.GetBool(_AP_DUMP_PYTHON_)

    pass



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  SALOME Logger : CORBA server managing trace output
#  File   : SALOME_Trace.py
#  Module : SALOME
#
import sys
import CosNaming
from omniORB import CORBA
import SALOME_Logger
import time
import os

trace="local"
if (os.environ.has_key("SALOME_trace")):
  if (os.environ["SALOME_trace"] == "with_logger"):
    trace="logger"

class SALOME_Trace :
    def __init__(self):
        self.m_pInterfaceLogger = None
        if trace=="logger":
            ok = 0
            steps = 40
            while steps > 0 and ok == 0:

              try:
                orb = CORBA.ORB_init(sys.argv, CORBA.ORB_ID)
                theObj = orb.resolve_initial_references("NameService")
                inc = theObj._narrow(CosNaming.NamingContext)
                name = [CosNaming.NameComponent("Logger","")]
                obj = inc.resolve(name);

                self.m_pInterfaceLogger = obj._narrow(SALOME_Logger.Logger)

                if not self.m_pInterfaceLogger is None:
                  ok = 1

              except CosNaming.NamingContext.NotFound, e :
                    if steps == 1: print "Caught exception: Naming Service can't found Logger"
              except (CORBA.TRANSIENT,CORBA.OBJECT_NOT_EXIST,CORBA.COMM_FAILURE):
                    if steps == 1: print "Caught CORBA::SystemException CommFailure"
              except CORBA.SystemException, e:
                    if steps == 1: print "Caught CORBA::SystemException."
              except CORBA.Exception, e:
                    if steps == 1: print "Caught CORBA::Exception."
              except Exception, e:
                    if steps == 1: print "Caught unknown exception."

              time.sleep(0.25)
              steps = steps - 1

    def putMessage ( self, LogMsg ) :
        if (CORBA.is_nil(self.m_pInterfaceLogger)):
            print  LogMsg;
        else:
            self.m_pInterfaceLogger.putMessage (LogMsg)



#! /usr/bin/env python
#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

## \file killSalome.py
#  Stop all %SALOME servers from all sessions by killing them
#

import os, sys, re, signal

from killSalomeWithPort import killMyPort, getPiDict
#from salome_utils import getHostName, getShortHostName

def killAllPorts():
    """
    Kill all SALOME sessions belonging to the user.
    """
    user = os.getenv('USER')
    #hostname  = getHostName()
    #shostname = getShortHostName()
    # new-style dot-prefixed pidict file
    #fpidict   = getPiDict('(\d*)',hidden=True)
    #problem with WIN32 path slashes
    fpidict   = getPiDict('#####',hidden=True)
    dirpidict = os.path.dirname(fpidict)
    fpidict   = os.path.basename(fpidict)
    #if hostname in fpidict:
    #    fpidict = fpidict.replace(hostname, shostname+".*")
    fpidict   = fpidict.replace('#####', '(\d*)')
    fnamere   = re.compile("^%s$" % fpidict)
    try:
        for f in os.listdir(dirpidict):
            mo = fnamere.match(f)
            try:
                killMyPort(mo.group(1))
            except:
                pass
            pass
        pass
    except:
        pass
    # provide compatibility with old-style pidict file (not dot-prefixed)
    #fpidict   = getPiDict('(\d*)',hidden=False)
    fpidict   = getPiDict('#####',hidden=False)
    dirpidict = os.path.dirname(fpidict)
    fpidict   = os.path.basename(fpidict)
    #if hostname in fpidict:
    #    fpidict = fpidict.replace(hostname, shostname+".*")
    fpidict = fpidict.replace('#####', '(\d*)')
    fnamere   = re.compile("^%s$" % fpidict)
    try:
        for f in os.listdir(dirpidict):
            mo = fnamere.match(f)
            try:
                killMyPort(mo.group(1))
            except:
                pass
            pass
        pass
    except:
        pass
    # kill other processes
    if sys.platform != 'win32':
        import commands
        cmd = "ps -fea | grep '%s' | grep 'ghs3d' | grep 'f /tmp/GHS3D_' | grep -v 'grep' | awk '{print $2}'" % user
        prc = commands.getoutput(cmd)
        for field in prc.split():
            try:
                os.kill(int(field), signal.SIGKILL)
            except:
                pass
            pass
        pass
    pass

if __name__ == "__main__":
    killAllPorts()
    pass
    



#!/usr/bin/env python
#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

import sys, os, string, glob, time, pickle
import orbmodule
from launchConfigureParser import verbose

# this file is extraction of set_env from runSalome.py
# for reusage in automated tests

# salome_subdir variable is used for composing paths like $KERNEL_ROOT_DIR/share/salome/resources, etc.
# before moving to SUIT-based gui, instead of salome_subdir there was args['appname'] used.
# but after - 'appname'  = "SalomeApp", so using it in making the subdirectory is an error.
salome_subdir = "salome"


# -----------------------------------------------------------------------------

def add_path(directory, variable_name):
    """Function helper to add environment variables"""
    if sys.platform == "win32":
      splitsym = ";"
    else:
      splitsym = ":"
    if not os.environ.has_key(variable_name):
        os.environ[variable_name] = ""
        pass
    if os.path.exists(directory):
        newpath=[]
        for _dir in os.environ[variable_name].split(splitsym):
            if os.path.exists(_dir):
                if sys.platform != "win32":
                    if not os.path.samefile(_dir, directory):
                        newpath.append(_dir)
                else:
                    newpath.append(_dir)
            else:
                if os.path.abspath(_dir) != os.path.abspath(directory):
                  newpath.append(_dir)
            pass
        import string
        newpath[:0] = [ directory ]
        newpath = string.join(newpath, splitsym)
        os.environ[variable_name] = newpath
        if variable_name == "PYTHONPATH":
            sys.path[:0] = [directory]

# -----------------------------------------------------------------------------

__lib__dir__ = None
def get_lib_dir():
    global __lib__dir__
    if __lib__dir__: return __lib__dir__
    import platform
    __lib__dir__ = "lib"
    return __lib__dir__

# -----------------------------------------------------------------------------

def get_config(silent=False):
    """
    Get list of modules, paths.
    
    Read args from launch configure xml file and command line options.
    Check variables <module>_ROOT_DIR and set list of used modules.
    Return args, modules_list, modules_root_dir    
    """
    
    # read args from launch configure xml file and command line options

    #*** Test additional option
    #*** import optparse
    #*** help_str = "Test options addition."
    #*** o_j = optparse.Option("-j", "--join", action="store_true", dest="join", help=help_str)

    import launchConfigureParser
    args = launchConfigureParser.get_env()

    #*** Test additional option
    #*** args = launchConfigureParser.get_env([o_j])
    #*** if args.has_key("join"): print args["join"]

    # Check variables <module>_ROOT_DIR
    # and set list of used modules (without KERNEL)

    modules_list = []
    if args.has_key("modules"):
        modules_list += args["modules"]
    # KERNEL must be last in the list to locate it at the first place in PATH
    if args["gui"] :
        modules_list[:0] = ["GUI"]
    modules_list[:0] = ["KERNEL"]
    modules_list.reverse()

    modules_root_dir = {}

    to_remove_list=[]
    for module in modules_list :
        module_variable=module+"_ROOT_DIR"
        if not os.environ.has_key(module_variable):
            if not silent:
                print "*******************************************************"
                print "*"
                print "* Environment variable",module_variable,"must be set"
                print "* Module", module, "will be not available"
                print "*"
                print "********************************************************"
                pass
            to_remove_list.append(module)
            continue
            pass
        module_root_dir = os.environ[module_variable]
        modules_root_dir[module]=module_root_dir

    for to_remove in to_remove_list:
        modules_list.remove(to_remove)

    while "KERNEL" in modules_list:
        modules_list.remove("KERNEL")
        pass

    while "GUI" in modules_list:
        modules_list.remove("GUI")
        pass

    return args, modules_list, modules_root_dir

# -----------------------------------------------------------------------------

def set_env(args, modules_list, modules_root_dir, silent=False):
    """Add to the PATH-variables modules specific paths"""
    
    import os
    from salome_utils import getTmpDir, generateFileName, makeTmpDir, getPortNumber

    # create temporary directory for environment files needed by modules from the list
    port = getPortNumber(False)
    if port:
        tmp_dir = getTmpDir()
        env_dir = generateFileName(tmp_dir, prefix="env", with_port=True)
        makeTmpDir(env_dir)
        pass

    python_version="python%d.%d" % sys.version_info[0:2]
    modules_root_dir_list = []
    if os.getenv('SALOME_BATCH') == None:
      os.putenv('SALOME_BATCH','0')
    if args["gui"] :
        modules_list = modules_list[:] + ["GUI"] 
    modules_list = modules_list[:] + ["KERNEL"] 
    for module in modules_list :
        if modules_root_dir.has_key(module):
            module_root_dir = modules_root_dir[module]
            modules_root_dir_list[:0] = [module_root_dir]
            if sys.platform == "win32":
              add_path(os.path.join(module_root_dir,get_lib_dir(),salome_subdir),
                     "PATH")
            else:
              add_path(os.path.join(module_root_dir,get_lib_dir(),salome_subdir),
                     "LD_LIBRARY_PATH")
            add_path(os.path.join(module_root_dir,"bin",salome_subdir),
                     "PATH")
            if os.path.exists(module_root_dir + "/examples") :
                add_path(os.path.join(module_root_dir,"examples"),
                         "PYTHONPATH")
                pass
            add_path(os.path.join(module_root_dir,"bin",salome_subdir),
                     "PYTHONPATH")
            # add lib before site-packages to load script instead of dll if any (win32 platform)
            add_path(os.path.join(module_root_dir,get_lib_dir(),salome_subdir),
                     "PYTHONPATH")
            add_path(os.path.join(module_root_dir,get_lib_dir(),
                                  python_version,"site-packages",
                                  salome_subdir),
                     "PYTHONPATH")
            import platform
            if platform.machine() == "x86_64":
                add_path(os.path.join(module_root_dir,"lib64",
                                      python_version,"site-packages",
                                      salome_subdir),
                         "PYTHONPATH")
                pass
            add_path(os.path.join(module_root_dir,get_lib_dir(),
                                  python_version,"site-packages",
                                  salome_subdir,
                                  "shared_modules"),
                     "PYTHONPATH")

            # set environment by modules from the list
            if port:
                try:
                    mod=__import__(module.lower()+"_setenv")
                    mod.set_env(args)
                    pass
                except:
                    pass
                pass
            pass
        pass

    if sys.platform == 'win32':
        os.environ["SALOMEPATH"]=";".join(modules_root_dir_list)
    else:
        os.environ["SALOMEPATH"]=":".join(modules_root_dir_list)
    
    # set trace environment variable
    
    if not os.environ.has_key("SALOME_trace"):
        os.environ["SALOME_trace"]="local"
    if args['file']:
        os.environ["SALOME_trace"]="file:"+args['file'][0]
    if args['logger']:
        os.environ["SALOME_trace"]="with_logger"

    # set resources variables if not yet set

    os.environ["CSF_SALOMEDS_ResourcesDefaults"] \
    = os.path.join(modules_root_dir["KERNEL"],"share",
                   salome_subdir,"resources","kernel")

# -----------------------------------------------------------------------------

def main(silent=False):
    args, modules_list, modules_root_dir = get_config(silent=silent)
    set_env(args, modules_list, modules_root_dir, silent=silent)
    return args

# -----------------------------------------------------------------------------

if __name__ == "__main__":
   import user
   args = main()



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

## @package salome_session
# \brief Module that provides the SalomeSession object that helps to launch
#        a SALOME script session
#

import os
import sys
import string
import socket

_session = None

def startSession(modules=[]):
    global _session
    if _session: return
    searchFreePort()
    _session = SalomeSession(modules)
    return

def getShortHostName():
    """
    gives Hostname without domain extension.
    SALOME naming service needs short Hostnames (without domain extension).
    HOSTNAME is not allways defined in environment,
    socket.gethostname() gives short or complete Hostname, depending on
    defined aliases.
    """
    from salome_utils import getShortHostName
    return getShortHostName()

def searchFreePort():
    """
    Search free port for SALOME session.
    Returns first found free port number.
    """
    print "Searching a free port for naming service:",
    from salome_utils import generateFileName, getHostName
    hostname = getHostName()
    NSPORT = 2810
    limit  = NSPORT+100
    while 1:
        print "%s "%(NSPORT),
        status = os.system("netstat -ltn | grep -E :%s"%(NSPORT))
        if status:
            home  = os.getenv("HOME")
            appli = os.getenv("APPLI")
            kwargs={}
            if appli is not None: 
              home = os.path.join(home, appli,"USERS")
              kwargs["with_username"]=True
            omniorb_config = generateFileName(home, prefix="omniORB",
                                              extension="cfg",
                                              hidden=True,
                                              with_hostname=True,
                                              with_port=NSPORT,
                                              **kwargs)
            f = open(omniorb_config, "w")
            f.write("ORBInitRef NameService=corbaname::%s:%s\n"%(hostname, NSPORT))
            f.close()
            os.environ['OMNIORB_CONFIG'] = omniorb_config
            last_running_config = generateFileName(home, prefix="omniORB",
                                                   suffix="last",
                                                   extension="cfg",
                                                   hidden=True,
                                                   **kwargs)
            os.environ['LAST_RUNNING_CONFIG'] = last_running_config
            if os.access(last_running_config,os.F_OK):
                os.unlink(last_running_config)
                pass
            os.symlink(omniorb_config,last_running_config)
            print "- Ok"
            break
        if NSPORT == limit:
            msg  = ""
            msg += "Can not find a free port to launch omniNames\n"
            msg += "Kill the running servers and try again.\n"
            raise RuntimeError, msg
        NSPORT = NSPORT+1
        pass
    os.environ['NSHOST'] = hostname
    os.environ['NSPORT'] = str(NSPORT)
    return NSPORT


class SalomeSession(object):
    """Salome session launcher"""
    import runSalome
    import killSalomeWithPort
    import killSalome
    def __init__(self, modules):
        import runSalome
        sys.argv  = ["dummy.py"]
        sys.argv += ["--terminal"]
        if modules:
            sys.argv += ['--modules=%s'%(",".join(modules))]
            pass
        runSalome.clt, runSalome.args = runSalome.main()
        import salome
        salome.salome_init()
        return
    def __del__(self):
        import runSalome
        runSalome.killLocalPort()
        return
    pass



# -*- coding: utf-8 -*-
#
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#
#  Author : Renaud Barate (EDF R&D)
#  Date   : August 2009
#
"""
This module provides utility functions to display colored text in the
terminal. It is based on ISO 6429 standard that defines control codes to
change characters representation in color-capable ASCII terminals.

In this module, colors are represented as lists of codes, so they can be added
to obtain special effects (e.g. RED + GREEN_BG to display red text on green
background). Several constants are defined for the most usual codes to
facilitate the use of colors, but it is also possible to define colors
directly from the corresponding code from ISO 6429 standard. In fact it is
even necessary for less usual codes that don't have an associated constant
(e.g. PURPLE + ['09'] can be used to display a crossed-out purple text).

Example::

    import sys
    from salome.kernel import termcolor
    if termcolor.canDisplayColor(sys.stdout):
        print termcolor.makeColoredMessage("Hello world!", termcolor.BLUE)
    else:
        print "Hello world!"

"""

# Constants for color codes
DEFAULT    = ['00']
"""Default color for the terminal"""
BOLD       = ['01']
"""Bold text and brighter colors"""
UNDERLINED = ['04']
"""Underlined text"""
BLACK_FG   = ['30']
"""Black foreground"""
RED_FG     = ['31']
"""Red foreground"""
GREEN_FG   = ['32']
"""Green foreground"""
YELLOW_FG  = ['33']
"""Yellow foreground"""
BLUE_FG    = ['34']
"""Blue foreground"""
PURPLE_FG  = ['35']
"""Purple foreground"""
CYAN_FG    = ['36']
"""Cyan foreground"""
WHITE_FG   = ['37']
"""White foreground"""
BLACK_BG   = ['40']
"""Black background"""
RED_BG     = ['41']
"""Red background"""
GREEN_BG   = ['42']
"""Green background"""
YELLOW_BG  = ['43']
"""Yellow background"""
BLUE_BG    = ['44']
"""Blue background"""
PURPLE_BG  = ['45']
"""Purple background"""
CYAN_BG    = ['46']
"""Cyan background"""
WHITE_BG   = ['47']
"""White background"""

# Constants for common colored text
BLACK      = BLACK_FG
"""Black text (equivalent to BLACK_FG)"""
RED        = BOLD + RED_FG
"""Red text (equivalent to BOLD + RED_FG)"""
GREEN      = BOLD + GREEN_FG
"""Green text (equivalent to BOLD + GREEN_FG)"""
YELLOW     = BOLD + YELLOW_FG
"""Yellow text (equivalent to BOLD + YELLOW_FG)"""
BLUE       = BOLD + BLUE_FG
"""Blue text (equivalent to BOLD + BLUE_FG)"""
PURPLE     = BOLD + PURPLE_FG
"""Purple text (equivalent to BOLD + PURPLE_FG)"""
CYAN       = BOLD + CYAN_FG
"""Cyan text (equivalent to BOLD + CYAN_FG)"""
WHITE      = WHITE_FG
"""White text (equivalent to WHITE_FG)"""


def canDisplayColor(stream):
    """
    Return True if the stream can display colored text, False otherwise.
    """
    return hasattr(stream, "isatty") and stream.isatty()

def getControlSequence(color):
    """
    Return the control sequence for the color in parameter, i.e. the string
    telling the terminal to display the following text in the given color.
    """
    seq = "\x1b["
    for i in range(len(color)):
        seq += color[i]
        if i < len(color)-1:
            seq += ";"
    seq += "m"
    return seq

def makeColoredMessage(message, color):
    """
    Return a string that can be used to display the message in parameter with
    the given color.
    """
    return (getControlSequence(color) +
            str(message) +
            getControlSequence(DEFAULT))

def TEST_termcolor():
    """Test function for termcolor module."""
    import sys
    if not canDisplayColor(sys.stdout):
        print "Standard output does not support colors."
        return
    print makeColoredMessage("This message must appear in blue.", BLUE)
    print makeColoredMessage("This message must appear in red on green " +
                             "background.", RED + GREEN_BG)
    print makeColoredMessage("This message must appear in magenta and " +
                             "crossed-out.", PURPLE + ['09'])


# Main function only used to test the module
if __name__ == "__main__":
    TEST_termcolor()



# -*- coding: iso-8859-1 -*-
# Copyright (C) 2010-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

__author__ = "gboulant"
__date__ = "$1 avr. 2010 09:08:02$"

class Enumerate(object):
    """
    This class emulates a C-like enum for python. It is initialized with a list
    of strings to be used as the enum symbolic keys. The enum values are automatically
    generated as sequencing integer starting at the specified offset value.
    """
    def __init__(self, keys, offset=0):
        """
        Canonical constructor
        @keys a list of string to be used as the enum symbolic keys. The enum values
        are automatically generated as a sequence of integers starting at the specified
        offset value.
        """
        self._dict_keynumbers = {}
        for number, key in enumerate(keys):
            value = offset + number
            setattr(self, key, value)
            self._dict_keynumbers[key] = value

    def contains(self, key):
        """
        Return true if this enumerate contains the specified key string
        @key a key string to test
        """
        return (key in self._dict_keynumbers.keys())

    def isValid(self, value):
        """
        Returns true if the specified integer value is defined as an identifier
        in this enumarate.
        @value a value to test
        """
        return (value in self._dict_keynumbers.values())

    def listkeys(self):
        """
        Returns the list of keys in this enumerate.
        """
        list = self._dict_keynumbers.keys()
        list.sort()
        return list

    def listvalues(self):
        """
        Returns the list of values specified to initiate this enumerate.
        """
        list = self._dict_keynumbers.values()
        list.sort()
        return list

    def keyOf(self, value):
        """
        Returns the symbolic key string associated to the specified identifier
        value.
        @param value : an integer value whose associated key string is requested.
        """
        if not self.isValid(value):
            return None
        # _MEM_ We assume here that the keys and associated values are in the
        # same order in their list.
        return self._dict_keynumbers.keys()[self._dict_keynumbers.values().index(value)]

        # If not, weshould use a longer implementation such that:
        #for key in self._dict_keynumbers.keys():
        #    if self._dict_keynumbers[key] == value:
        #        return key

#
# ==============================================================================
# Basic use cases and unit test functions
# ==============================================================================
#

def TEST_simple():
    TYPES_LIST = Enumerate([
        'SEP',
        'OTHER'
    ])
    print TYPES_LIST.listvalues()
    return True

def TEST_createFromList():
    codes = Enumerate([
        'KERNEL', # This should take the value 0
        'GUI', # This should take the value 1
        'GEOM', # ...
        'MED',
        'SMESH'])

    print codes.KERNEL
    print codes.GEOM
    if (codes.KERNEL == 0 and codes.GEOM == 2):
        return True
    else:
        return False

def TEST_createFromString():
    aList = "KERNEL GUI GEOM MED"

    codes = Enumerate(aList.split())

    print codes.KERNEL
    print codes.GEOM
    if (codes.KERNEL == 0 and codes.GEOM == 2):
        return True
    else:
        return False

def TEST_contains():
    codes = Enumerate([
        'KERNEL', # This should take the value 0
        'GUI', # This should take the value 1
        'GEOM', # ...
        'MED',
        'SMESH'])

    print "VISU in enumerate?", codes.contains("VISU")
    if (not codes.contains("VISU")):
        return True
    else:
        return False

def TEST_isValid():
    codes = Enumerate([
        'KERNEL', # This should take the value 0
        'GUI', # This should take the value 1
        'GEOM', # ...
        'MED',
        'SMESH'])

    if (not codes.isValid(23)):
        return True
    else:
        return False

def TEST_offset():
    codes = Enumerate([
        'KERNEL', # This should take the value 0
        'GUI', # This should take the value 1
        'GEOM', # ...
        'MED',
        'SMESH'], offset=20)

    print codes.KERNEL
    print codes.GEOM
    if (codes.KERNEL == 20 and codes.GEOM == 22):
        return True
    else:
        return False

def TEST_listvalues():
    codes = Enumerate([
        'KERNEL', # This should take the value 0
        'GUI', # This should take the value 1
        'GEOM', # ...
        'MED',
        'SMESH'], offset=20)

    print codes.listvalues()
    if codes.listvalues() != [20, 21, 22, 23, 24]:
        return False
    return True

def TEST_keyOf():
    codes = Enumerate([
        'KERNEL', # This should take the value 0
        'GUI', # This should take the value 1
        'GEOM', # ...
        'MED',
        'SMESH'])

    if ( codes.keyOf(codes.KERNEL) != 'KERNEL' or
         codes.keyOf(codes.GUI) != 'GUI' or
         codes.keyOf(codes.GEOM) != 'GEOM' or
         codes.keyOf(codes.MED) != 'MED' or
         codes.keyOf(codes.SMESH) != 'SMESH'):
            return False
    return True

if __name__ == "__main__":
    import unittester
    unittester.run("enumerate", "TEST_simple")
    unittester.run("enumerate", "TEST_createFromList")
    unittester.run("enumerate", "TEST_createFromString")
    unittester.run("enumerate", "TEST_contains")
    unittester.run("enumerate", "TEST_isValid")
    unittester.run("enumerate", "TEST_offset")
    unittester.run("enumerate", "TEST_listvalues")
    unittester.run("enumerate", "TEST_keyOf")



#!/usr/bin/env python
#  -*- coding: utf-8 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

"""
"""
import sys,os,shutil,glob,socket
import optparse

import getAppliPath
appli_local=os.path.realpath(os.path.dirname(__file__))
APPLI=getAppliPath.relpath(appli_local,os.path.realpath(os.getenv('HOME')))

usage="""usage: %prog [options]
Typical use is:
  python update_catalogs.py

You need to have a well installed SALOME application with a CatalogResources.base.xml file.
This file is used (parsed) to collect all module catalogs from distant resources and
put them in the directory "remote_catalogs" with sub-directories with same name as the distant resource.
Distant resources are all the resources except the main SALOME application.
Module catalogs from distant resources are copied by the remote protocol declared in the catalog (rcp or rsh)
except for the user resources on the local machine (local copy: cp).

In a second time, this procedure generates a ready to use CatalogResources.xml with all available components
for each resource.
"""

try:
  # cElementTree from Python 2.5+
  import xml.etree.cElementTree as etree_
except ImportError:
  try:
    import xml.etree.ElementTree as etree_
  except ImportError:
    try:
      import cElementTree as etree_
    except ImportError:
      try:
        # normal ElementTree install
        import elementtree.ElementTree as etree_
      except ImportError:
        raise

class ParseError(Exception):
  pass

catalog_file_base=os.path.join(appli_local,"CatalogResources.base.xml")
catalog_file=os.path.join(appli_local,"CatalogResources.xml")

cata_dir=os.path.join(appli_local,"remote_catalogs")
cata_dir_bak=os.path.join(appli_local,"remote_catalogs.bak")

SEP=":"
if sys.platform == "win32":SEP=";"

def get_hostname():
  return socket.gethostname().split('.')[0]

class Component:
  """Define a SALOME component
      - name : component name
      - moduleName : module name
  """
  def __init__(self,name,moduleName):
    self.name=name
    self.moduleName=moduleName

class Resource:
  """Define a SALOME resource
     - components : the list of available components of the resource
  """
  def __init__(self,node):
    self.node=node
    self.components=[]
    self.resource_dir=None
    self.build()

  def build(self):
    self.attrs=self.node.attrib
    #remove all children (components and modules)
    for child in list(self.node):
      self.node.remove(child)

  def update(self):
    for compo in self.components:
      child=etree_.Element("component",name=compo.name,moduleName=compo.moduleName)
      child.tail="\n"
      self.node.append(child)

  def get_rcp(self):
    protocol= self.node.get("protocol")
    if protocol and protocol[0]=='s':return "scp"
    else:return "rcp"

  def get_user(self):
    userName= self.node.get("userName")
    if not userName:
      userName=os.getenv('USER')
    return userName

  def get_host(self):
    hostname= self.node.get("hostname")
    return hostname

  def get_name(self):
    name= self.node.get("name")
    if name:return name
    return self.get_host()

  def get_appliPath(self):
    appliPath= self.node.get("appliPath")
    if appliPath is None:
      appliPath=APPLI
    return appliPath

  def get_catalogs(self):
    """Get module catalogs file from the resource and copy them locally in remote_catalogs/<resource name>"""
    hostname=self.get_host()
    appliPath= self.get_appliPath()
    userName = self.get_user()
    rcopy=self.get_rcp()

    resource_dir=os.path.join(cata_dir,self.get_name())

    if hostname == "localhost" or hostname == get_hostname() and userName == os.getenv("USER"):
      #local machine, use cp
      if appliPath[0]!='/':
        #relative path
        appliPath=os.path.join(os.getenv("HOME"),appliPath)

      if appliPath == appli_local:
        return
      os.mkdir(resource_dir)
      cata_path=os.path.join(appliPath,"share","salome","resources","*Catalog.xml")
      cmd="cp %s %s" % (cata_path,resource_dir)
      print cmd
      os.system(cmd)
      cata_path=os.path.join(appliPath,"share","salome","resources","*","*Catalog.xml")
      cmd="cp %s %s" % (cata_path,resource_dir)
      print cmd
      os.system(cmd)
    else:
      #remote machine, use rcopy
      os.mkdir(resource_dir)
      cata_path=os.path.join(appliPath,"share","salome","resources","*Catalog.xml")
      cmd="%s %s@%s:%s %s"
      cmd= cmd%(rcopy,userName,hostname,cata_path,resource_dir)
      print cmd
      os.system(cmd)
      cata_path=os.path.join(appliPath,"share","salome","resources","*","*Catalog.xml")
      cmd="%s %s@%s:%s %s"
      cmd= cmd%(rcopy,userName,hostname,cata_path,resource_dir)
      print cmd
      os.system(cmd)

    schema_cata=os.path.join(resource_dir,"*SchemaCatalog.xml")
    os.system("rm %s"% schema_cata)

    self.resource_dir=os.path.abspath(resource_dir)

  def get_components(self):
    """Retrieve all components declared in module catalogs of the resource"""
    appliPath= self.get_appliPath()
    userName = self.get_user()
    hostname=self.get_host()
    resource_dir=os.path.join(cata_dir,self.get_name())
    catalogs_list=glob.glob(os.path.join(resource_dir,"*Catalog.xml"))

    if hostname == "localhost" or hostname == get_hostname() and userName == os.getenv("USER"):
      #user local resource
      if appliPath[0]!='/':
        appliPath=os.path.join(os.getenv("HOME"),appliPath)
      if appliPath == appli_local:
        #main local resource: get catalogs in share/salome/resources
        catalogs_list=glob.glob(os.path.join(appliPath,"share","salome","resources","*","*Catalog.xml"))
        catalogs_list=catalogs_list + glob.glob(os.path.join(appliPath,"share","salome","resources","*Catalog.xml"))

    for cata in catalogs_list:
      moduleName= os.path.basename(cata)[:-11]
      #Parse module catalog
      doc = etree_.parse(cata)
      rootNode = doc.getroot()
      for componentName in rootNode.findall("component-list/component/component-name"):
        self.components.append(Component(componentName.text,moduleName))


def main():
  parser = optparse.OptionParser(usage=usage)

  options, args = parser.parse_args()

  if not os.path.exists(catalog_file_base):
    print "ERROR: the base catalog file %s is mandatory" % catalog_file_base
    sys.exit(1)

  #Parse CatalogResource.xml
  doc = etree_.parse(catalog_file_base)

  rootNode = doc.getroot()
  if rootNode.tag != "resources":
    raise  ParseError("First level tag must be resources not %s" % rootNode.tag)

  resources=[]

  #Extract resources
  for child in rootNode:
    if child.tag != "machine":
      raise  ParseError("Second level tag must be machine not %s" % child.tag)
    resources.append(Resource(child))

  # Remove remote_catalogs directory and create a new empty one
  if os.path.exists(cata_dir):
    if os.path.exists(cata_dir_bak):
      shutil.rmtree(cata_dir_bak)
    os.rename(cata_dir,cata_dir_bak)

  os.mkdir(cata_dir)

  #Get catalogs from remote resources and copy them in remote_catalogs
  for mach in resources:
    mach.get_catalogs()

  #Get the list of SALOME components that are defined in catalogs
  for mach in resources:
    mach.get_components()

  #Update the resource catalog dom object for further dump
  for mach in resources:
    mach.update()

  #dump new CatalogResources.xml
  f=open(catalog_file,'w')
  f.write('<?xml version="1.0" ?>\n')
  doc.write(f)
  f.write('\n')
  f.close()
  print "%s updated" % catalog_file

  #update configRemote.sh in env.d directory (environment variable SALOME_CATALOGS_PATH)
  path=[]
  for mach in resources:
    if mach.resource_dir:
      path.append(mach.resource_dir)

  f=open(os.path.join(appli_local,"env.d","configRemote.sh"),'w')
  f.write("export SALOME_CATALOGS_PATH=%s\n" % SEP.join(path))
  f.close()


if __name__ == '__main__':
  main()




#! /usr/bin/env python
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  SALOME TestContainer : test of container creation and its life cycle
#  File   : TestComponentPy.py
#  Author : Paul RASCLE, EDF
#  Module : SALOME
#  $Header: /home/server/cvs/KERNEL/KERNEL_SRC/src/TestContainer/TestComponentPy.py,v 1.9.30.2.12.1 2012-04-12 14:05:31 vsr Exp $
#
import os
import sys
import string
from omniORB import CORBA
import CosNaming
import Engines
from Utils_Identity import getShortHostName


#initialise the ORB
orb = CORBA.ORB_init(sys.argv, CORBA.ORB_ID)

#obtain a reference to the root naming context
obj = orb.resolve_initial_references("NameService")
rootContext = obj._narrow(CosNaming.NamingContext)

if rootContext is None:
    print "Name Service Reference is invalid"
    sys.exit(1)

#resolve the name /Containers.dir/FactoryServerPy.object
machineName=getShortHostName()
containerName = "FactoryServerPy"
name = [CosNaming.NameComponent("Containers","dir"),
        CosNaming.NameComponent(machineName,"dir"),
        CosNaming.NameComponent(containerName,"object")]

try:
    obj = rootContext.resolve(name)
except CosNaming.NamingContext.NotFound, ex:
    print  containerName , " not found in Naming Service"
    sys.exit(1)

container = obj._narrow(Engines.Container)
print container.getHostName()
comp = container.load_impl("SALOME_TestComponentPy","SALOME_TestComponentPy")
print comp._get_instanceName()
comp.ping()
comptest = comp._narrow(Engines.TestComponent)
if comptest is None:
    print "probleme cast"
print comptest.Coucou(1)





#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

## @package dsccalcium
# \brief Module that provides the base class for DSC components implemented in python
#

import calcium
import SALOME_ComponentPy
import SALOME_DriverPy
import Engines

## The SALOME base class for all DSC components implemented in python (interface Engines::Superv_Component).
#
#
class PyDSCComponent(SALOME_ComponentPy.SALOME_ComponentPy_i,
                     SALOME_DriverPy.SALOME_DriverPy_i):
  """
     A Python DSC component is implemented by a Python class that has
     the name of the component and is located in a python module that has the
     name of the component.

     You must derive it and implement init_service and those methods
     that are services of the component.
  """
  def __init__ ( self, orb, poa, contID, containerName, instanceName, interfaceName ):
    SALOME_ComponentPy.SALOME_ComponentPy_i.__init__(self, orb, poa,
                    contID, containerName, instanceName, interfaceName, 0)
    SALOME_DriverPy.SALOME_DriverPy_i.__init__(self, interfaceName)
    # create the DSC proxy
    self.proxy=calcium.PySupervCompo(orb,poa,contID,instanceName,interfaceName )
    # Store a reference on naming service in _naming_service attribute 
    self._naming_service = SALOME_ComponentPy.SALOME_NamingServicePy_i( self._orb )

  def init_service(self,service):
    return True

  enums={Engines.DSC.RemovingConnection:calcium.DSC.RemovingConnection,
         Engines.DSC.AddingConnection:calcium.DSC.AddingConnection,
         Engines.DSC.ApplicationError:calcium.DSC.ApplicationError,
        }
  def get_provides_port(self,name,error):
    return self.proxy.get_provides_port(name,error)

  def connect_uses_port(self,name,port):
    self.proxy.connect_uses_port(name,port)

  def connect_provides_port(self,name):
    self.proxy.connect_provides_port(name)

  def disconnect_provides_port(self,name,message):
    self.proxy.disconnect_provides_port(name,message._v)
    #self.proxy.disconnect_provides_port(name,self.enums[message])

  def disconnect_uses_port(self,name,port,message):
    self.proxy.disconnect_uses_port(name,port,message._v)
    #self.proxy.disconnect_uses_port(name,port,self.enums[message])

  def get_port_properties(self,name):
    return self.proxy.get_port_properties(name)

  def setInputFileToService(self,service_name,Salome_file_name):
    return self.proxy.setInputFileToService(service_name,Salome_file_name)

  def checkInputFilesToService(self,service_name):
    return self.proxy.checkInputFilesToService(service_name)

  def getInputFileToService(self,service_name,Salome_file_name):
    return self.proxy.getInputFileToService(service_name,Salome_file_name)

  def setOutputFileToService(self,service_name,Salome_file_name):
    return self.proxy.setOutputFileToService(service_name,Salome_file_name)

  def getOutputFileToService(self,service_name,Salome_file_name):
    return self.proxy.getOutputFileToService(service_name,Salome_file_name)

  def checkOutputFilesToService(self,service_name):
    return self.proxy.checkOutputFilesToService(service_name)

  def beginService(self,service_name):
    SALOME_ComponentPy.SALOME_ComponentPy_i.beginService(self,service_name)
    self.proxy.setTimeOut()




#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

print
print "Perform quick test of the application by loading of the GEOM, SMESH, VISU, MED"
print "components and doing some operation within the components."
print

import salome
import SALOME
import SALOMEDS
import os
import sys
import SALOME_ModuleCatalog

step = 1

print "======================================================================"
print "           %d. Initialize study " % step; step+=1
print "======================================================================"

# initialize study
salome.salome_init()
# get study builder
builder = salome.myStudy.NewBuilder()
print "OK"

print 

print "======================================================================"
print "           %d. Retrieve module catalog " % step; step+=1
print "======================================================================"

obj = salome.naming_service.Resolve('Kernel/ModulCatalog')
catalog = obj._narrow(SALOME_ModuleCatalog.ModuleCatalog)
if not catalog:
    raise RuntimeError, "Can't accesss module catalog"
print "OK"

print

print "======================================================================"
print "           %d. Check modules availability in the module catalog " % step; step+=1
print "======================================================================"

print
print "--- Check GEOM ..."
comp = catalog.GetComponent("GEOM")
if not comp:
    raise RuntimeError, "Component GEOM is not found in Module Catalog."
print "OK"

print
print "--- Check SMESH ..."
comp = catalog.GetComponent("SMESH")
if not comp:
    raise RuntimeError, "Component SMESH is not found in Module Catalog."
print "OK"

print
print "--- Check MED ..."
comp = catalog.GetComponent("MED")
if not comp:
    raise RuntimeError, "Component MED is not found in Module Catalog."
print "OK"

print
print "--- Check VISU ..."
comp = catalog.GetComponent("VISU")
if not comp:
    raise RuntimeError, "Component VISU is not found in Module Catalog."
print "OK"

print

print "======================================================================"
print "           %d. Test Data Server " % step; step+=1
print "======================================================================"

print
print "--- Create new component ..."
comp = builder.NewComponent("TEST")
if not comp:
    raise RuntimeError, "Can't create new component"
print "OK"

print
print "--- Create AttributeName ..."
A = builder.FindOrCreateAttribute(comp, "AttributeName")
if not A:
    raise RuntimeError, "Can't create AttributeName attribute"
A.SetValue("TEST")
if A.Value() != "TEST":
    raise RuntimeError, "Error : wrong value of  AttributeName"
print "OK"

print
print "--- Create AttributeReal ..."
A = builder.FindOrCreateAttribute(comp, "AttributeReal")
if not A:
    raise RuntimeError, "Can't create AttributeReal attribute"
A.SetValue(0.0001)
if A.Value() != 0.0001:
    raise RuntimeError, "Error : wrong value of  AttributeReal"
print "OK"

print

print "======================================================================"
print "           %d. Test Geometry " % step; step+=1
print "======================================================================"

import geompy

ShapeTypeCompSolid = 1
ShapeTypeSolid = 2
ShapeTypeShell = 3
ShapeTypeFace = 4
ShapeTypeWire = 5
ShapeTypeEdge = 6
ShapeTypeVertex = 7

print
print "--- Create a box ..."
box = geompy.MakeBox(0., 0., 0., 100., 200., 300.)
idbox = geompy.addToStudy(box, "box")
box_obj = salome.myStudy.FindObjectByPath("/Geometry/box")
if not box_obj:
    raise RuntimeError, "Error : wrong value of  AttributeReal"
print "OK"

# ---- add shell from box in study
print 
print "--- Extract shell ..."
subShellList = geompy.SubShapeAll(box, ShapeTypeShell)
shell = subShellList[0]
name = geompy.SubShapeName(shell, box)
idshell = geompy.addToStudyInFather(box, shell, name)
print name
print "OK"

# ---- add first face of box in study
print 
print "--- Extract face ..."
subShapeList = geompy.SubShapeAll(box, ShapeTypeFace)
face = subShapeList[0]
name = geompy.SubShapeName(face, box)
idface = geompy.addToStudyInFather(box, face, name)
print name
print "OK"

# ---- add first edge of face in study
print 
print "--- Extract edge ..."
edgeList = geompy.SubShapeAll(face, ShapeTypeEdge)
edge = edgeList[0];
name = geompy.SubShapeName(edge, face)
idedge = geompy.addToStudyInFather(face, edge, name)
print name
print "OK"

# ---- update object browser
if salome.hasDesktop():
    salome.sg.updateObjBrowser(1);

print

print "======================================================================"
print "           %d. Test Mesh " % step; step+=1
print "======================================================================"

import StdMeshers
import SMESH

smesh = salome.lcc.FindOrLoadComponent("FactoryServer", "SMESH")
if salome.hasDesktop():
    smeshgui = salome.ImportComponentGUI("SMESH")
    smeshgui.Init(salome.myStudyId);
else:
    smesh.SetCurrentStudy(salome.myStudy)

# ---- create hypotheses 

if sys.platform == "win32":
  stdMeshersEngine = "StdMeshersEngine"
else:
  stdMeshersEngine = "libStdMeshersEngine.so"

print
print "--- Create hypotheses ..."

print
print "------ LocalLength ..."
hypLen1 = smesh.CreateHypothesis( "LocalLength", stdMeshersEngine )
hypLen1.SetLength(100)
print hypLen1.GetName()
print hypLen1.GetId()
print hypLen1.GetLength()
if salome.hasDesktop():
    smeshgui.SetName(salome.ObjectToID(hypLen1), "Local_Length_100")
print "OK"

print
print "------ NumberOfSegments ..."
hypNbSeg1= smesh.CreateHypothesis( "NumberOfSegments", stdMeshersEngine )
hypNbSeg1.SetNumberOfSegments(7)
print hypNbSeg1.GetName()
print hypNbSeg1.GetId()
print hypNbSeg1.GetNumberOfSegments()
if salome.hasDesktop():
    smeshgui.SetName(salome.ObjectToID(hypNbSeg1), "NumberOfSegments_7")
print "OK"

print
print "------ MaxElementArea [1] ..."
hypArea1 = smesh.CreateHypothesis( "MaxElementArea", stdMeshersEngine )
hypArea1.SetMaxElementArea(2500)
print hypArea1.GetName()
print hypArea1.GetId()
print hypArea1.GetMaxElementArea()
if salome.hasDesktop():
    smeshgui.SetName(salome.ObjectToID(hypArea1), "MaxElementArea_2500")
print "OK"

print
print "------ MaxElementArea [2] ..."
hypArea2 = smesh.CreateHypothesis( "MaxElementArea", stdMeshersEngine )
hypArea2.SetMaxElementArea(500)
print hypArea2.GetName()
print hypArea2.GetId()
print hypArea2.GetMaxElementArea()
if salome.hasDesktop():
    smeshgui.SetName(salome.ObjectToID(hypArea2), "MaxElementArea_500")
print "OK"

# ---- create algorithms

print
print "--- Create algorithms ..."

print
print "------ Regular_1D ..."
algoReg = smesh.CreateHypothesis( "Regular_1D", stdMeshersEngine )
listHyp = algoReg.GetCompatibleHypothesis()
for hyp in listHyp:
    print hyp
print algoReg.GetName()
print algoReg.GetId()
if salome.hasDesktop():
    smeshgui.SetName(salome.ObjectToID(algoReg), "Regular_1D" )
print "OK"

print
print "------ MEFISTO_2D ..."
algoMef = smesh.CreateHypothesis( "MEFISTO_2D", stdMeshersEngine )
listHyp=algoMef.GetCompatibleHypothesis()
for hyp in listHyp:
    print hyp
print algoMef.GetName()
print algoMef.GetId()
if salome.hasDesktop():
    smeshgui.SetName(salome.ObjectToID(algoMef), "MEFISTO_2D" )
print "OK"

# ---- create mesh on the box, apply hypotheses / algorithms

print
print "--- Create mesh on the box ..."
mesh = smesh.CreateMesh(box)
if salome.hasDesktop():
    smeshgui.SetName( salome.ObjectToID(mesh), "MeshBox" );
ret = mesh.AddHypothesis(box, algoReg)
ret = mesh.AddHypothesis(box, algoMef)
ret = mesh.AddHypothesis(box, hypNbSeg1)
ret = mesh.AddHypothesis(box, hypArea1)
print "OK"

# ---- create submesh on the edge, add hypothesis

print
print "--- Add 1D sub-mesh on the edge ..."
submesh = mesh.GetSubMesh(edge, "SubMeshEdge")
ret = mesh.AddHypothesis(edge, algoReg)
ret = mesh.AddHypothesis(edge, hypLen1)
print "OK"

# ---- create submesh on the edge, add hypothesis

print
print "--- Add 2D sub-mesh on the face ..."
submesh = mesh.GetSubMesh(face, "SubMeshFace")
ret = mesh.AddHypothesis(face, hypArea2)
print "OK"

# ---- compute mesh
print
print "--- Compute mesh ..."
smesh.Compute(mesh, box)
print "OK"

# ---- update object browser
if salome.hasDesktop():
    salome.sg.updateObjBrowser(1);

print

print "======================================================================"
print "           %d. Test Med " % step; step+=1
print "======================================================================"

import SALOME_MED

medFileName = "pointe.med"
medFile = os.path.join(os.getenv('DATA_DIR'), 'MedFiles', medFileName)

med_comp = salome.myStudy.FindComponent("MED")

if not med_comp:
    med  = salome.lcc.FindOrLoadComponent("FactoryServer", "MED")

    print
    print "--- Read med file structure from %s ..." % medFile
    med.readStructFileWithFieldType(medFile, salome.myStudyName)
    print "OK"
    pass
else:
    print
    print "This script cannot work properly, because there is"
    print "some MED component data already existing in the study."
    print "Execution aborted."
    print
    print "Skipping test for MED..."
    pass

print

print "======================================================================"
print "           %d. Test Post-Pro " % step; step+=1
print "======================================================================"

import VISU

aMeshName = "maa1"
anEntity = VISU.NODE
field_name = "fieldnodedouble"

if salome.hasDesktop(): # in gui mode
    
    import visu_gui
    visu = salome.lcc.FindOrLoadComponent("FactoryServer", "VISU")

    if not med_comp:
        
        print
        print "--- Get med object from study ..."
        med_obj = visu_gui.visu.getMedObjectFromStudy()
        if not med_obj:
            raise RuntimeError, "Med object is not found in the study"
        print "OK"

        print
        print "--- Get field from study ..."
        field = visu_gui.visu.getFieldObjectFromStudy(3,1)
        if not field:
            raise RuntimeError, "Field object is not found in the study"
        print "OK"

        print
        print "--- Import field to the VISU ..."
        aTimeStampId = -1
        result1 = visu.ImportMedField(field)
        if not result1:
            raise RuntimeError, "Can't import field"
        print "OK"

        print
        print "--- Create mesh presentation ..."
        mesh1 = visu.MeshOnEntity(result1, aMeshName, anEntity);
        if not mesh1:
            raise RuntimeError, "Can't create mesh presentation"
        print "OK"

        print
        print "--- Create scalar map ..."
        scalarMap1 = visu.ScalarMapOnField(result1, aMeshName, anEntity, field_name, aTimeStampId)
        if not scalarMap1:
            raise RuntimeError, "Can't create scalar map"
        print "OK"

        pass # if not med_comp

    print
    print "--- Import med file %s to the VISU ..." % medFile
    result2 = visu.ImportFile(medFile);
    if not result2:
        raise RuntimeError, "Can't import file"
    print "OK"

    print
    print "--- Create mesh presentation ..."
    mesh2 = visu.MeshOnEntity(result2, aMeshName, anEntity);
    if not mesh2:
        raise RuntimeError, "Can't create mesh presentation"
    print "OK"

    print
    print "--- Create scalar map ..."
    scalarMap2 = visu.ScalarMapOnField(result2, aMeshName, anEntity, field_name, 3)
    if not scalarMap2:
        raise RuntimeError, "Can't create scalar map"
    print "OK"
    pass

else: # not in gui mode, visu can not be tested
    
    print
    print "VISU module requires SALOME to be running in GUI mode."
    print
    print "Skipping test for VISU..."
    pass

# ---- update object browser
if salome.hasDesktop():
    salome.sg.updateObjBrowser(1);



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  File   : salome_kernel.py
#  Author : Paul RASCLE, EDF
#  Module : SALOME
#  $Header: /home/server/cvs/KERNEL/KERNEL_SRC/src/KERNEL_PY/salome_kernel.py,v 1.4.2.2.14.2.12.1 2012-04-12 14:05:13 vsr Exp $
#
from omniORB import CORBA
from LifeCycleCORBA import *
from SALOME_NamingServicePy import *
from SALOME_utilities import *
import Engines

salome_kernel_initial=1

def salome_kernel_init():
    global salome_kernel_initial
    global orb, lcc, naming_service, cm
    
    if salome_kernel_initial:
        salome_kernel_initial = 0
        
        # initialise the ORB
        orb = CORBA.ORB_init([''], CORBA.ORB_ID)

        # create a LifeCycleCORBA instance
        lcc = LifeCycleCORBA(orb)

        #create a naming service instance
        naming_service = SALOME_NamingServicePy_i(orb)

        # get Container Manager
        obj = naming_service.Resolve('/ContainerManager')
        cm = obj._narrow(Engines.ContainerManager)

    return orb, lcc, naming_service, cm



# -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

__author__="gboulant"
__date__ ="$21 mai 2010 18:00:23$"


# search a dictionary for key or value
# using named functions or a class
# tested with Python25   by Ene Uran    01/19/2008

def find_key(dic, val):
    """return the key of dictionary dic given the value"""
    return [k for k, v in dic.iteritems() if v == val][0]

def find_value(dic, key):
    """return the value of dictionary dic given the key"""
    return dic[key]

class Lookup(dict):
    """
    a dictionary which can lookup value by key, or keys by value
    """
    def __init__(self, items=[]):
        """items can be a list of pair_lists or a dictionary"""
        dict.__init__(self, items)

    def get_keys(self, value):
        """find the key(s) as a list given a value"""
        return [item[0] for item in self.items() if item[1] == value]

    def get_key(self, value):
        """
        find the key associated to the given a value. If several keys exist,
        only the first is given. To get the whole list, use get_keys instead.
        """
        list = self.get_keys(value)
        if len(list) == 0:
            return None
        return list[0]

    def get_value(self, key):
        """find the value given a key"""
        return self[key]

#
# ==============================================================================
# Use cases and unit tests
# ==============================================================================
#
def TEST_getTestDictionnary():
    # dictionary of chemical symbols
    symbol_dic = {
    'C': 'carbon',
    'H': 'hydrogen',
    'N': 'nitrogen',
    'Li': 'lithium',
    'Be': 'beryllium',
    'B': 'boron'
    }
    return symbol_dic

def TEST_find_value():
    symbol_dic = TEST_getTestDictionnary()
    print find_key(symbol_dic, 'boron')  # B
    print find_value(symbol_dic, 'B')    # boron
    print find_value(symbol_dic, 'H')    # hydrogen
    if find_key(symbol_dic, 'nitrogen') != 'N':
        return False
    return True

def TEST_lookup():
    symbol_dic = TEST_getTestDictionnary()

    name = 'lithium'
    symbol = 'Li'
    # use a dictionary as initialization argument
    look = Lookup(symbol_dic)
    print look.get_key(name)      # [Li']
    if look.get_key(name) != symbol:
        print "get "+str(look.get_key(name))+" while "+str(symbol)+" was expected"
        return False
    print look.get_value(symbol)  # lithium

    # use a list of pairs instead of a dictionary as initialization argument
    # (will be converted to a dictionary by the class internally)
    age_list = [['Fred', 23], ['Larry', 28], ['Ene', 23]]
    look2 = Lookup(age_list)
    print look2.get_keys(23)        # ['Ene', 'Fred']
    if look2.get_keys(23)[0] != 'Ene' or look2.get_keys(23)[1] != 'Fred':
        print "get "+str(look2.get_keys(23))+" while ['Ene', 'Fred'] was expected"
        return False
    print look2.get_value('Fred')  # 23
    return True

if __name__ == '__main__':
    import unittester
    unittester.run("diclookup", "TEST_find_value")
    unittester.run("diclookup", "TEST_lookup")



#! /usr/bin/env python
#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  SALOME Container : implementation of container and engine for Kernel
#  File   : SALOME_ContainerPy.py
#  Author : Paul RASCLE, EDF
#  Module : SALOME
#  $Header: /home/server/cvs/KERNEL/KERNEL_SRC/src/Container/SALOME_ContainerPy.py,v 1.12.2.2.14.3.2.1 2012-04-12 14:05:03 vsr Exp $
#
import os
import sys
import string

from omniORB import CORBA, PortableServer
import SALOMEDS 
import Engines, Engines__POA
from SALOME_NamingServicePy import *
from SALOME_ComponentPy import *

from SALOME_utilities import *
from Utils_Identity import getShortHostName
from launchConfigureParser import verbose

#=============================================================================

#define an implementation of the container interface for the container implemented in Python

class SALOME_ContainerPy_i (Engines__POA.Container):
    _orb = None
    _poa = None
    _numInstance = 0
    _listInstances_map = {}

    #-------------------------------------------------------------------------

    def __init__(self, orb, poa, containerName):
        MESSAGE( "SALOME_ContainerPy_i::__init__" )
        self._orb = orb
        self._poa = poa
        myMachine=getShortHostName()
        Container_path = "/Containers/" + myMachine + "/" + containerName
        self._containerName = Container_path
        if verbose(): print "container name ",self._containerName

        naming_service = SALOME_NamingServicePy_i(self._orb)
        self._naming_service = naming_service
        MESSAGE( str(Container_path) )
        naming_service.Register(self._this(), Container_path)
            
    #-------------------------------------------------------------------------

    def start_impl(self, ContainerName):
        MESSAGE(  "SALOME_ContainerPy_i::start_impl " + str(ContainerName) )
        myMachine=getShortHostName()
        theContainer = "/Containers/" + myMachine + "/" + ContainerName
        try:
            obj = self._naming_service.Resolve(theContainer)
        except :
            obj = None
            MESSAGE(  "SALOME_ContainerPy_i::start_impl " + str(ContainerName) + ".object not found in Naming Service" )
        if obj is None:
            container = None
        else:
            container = obj._narrow(Engines.Container)
            if container is None:
                MESSAGE( "SALOME_ContainerPy_i::start_impl " + str(containerName) + ".object exists but is not a Container" )
            else :
                MESSAGE( "SALOME_ContainerPy_i::start_impl " + str(ContainerName) + ".object found without new launch" )
            return container
        #shstr = os.getenv( "PWD" ) + "/"
        #shstr += "runSession ./SALOME_ContainerPy.py "
        shstr = os.getenv("KERNEL_ROOT_DIR") + "/bin/salome/SALOME_ContainerPy.py ";
        #shstr = "runSession SALOME_ContainerPy.py "
        shstr += ContainerName

        # mpv: fix for SAL4731 - allways create new file to write log of server
        num = 1
        fileName = ""
        while 1:
            fileName = "/tmp/"+ContainerName+"_%i.log"%num
            if not os.path.exists(fileName):
                break
            num += 1
            pass
        
        shstr += " > "
        shstr += fileName
        shstr += " 2>&1 &"
        
        #shstr += " > /tmp/"
        #shstr += ContainerName
        #shstr += ".log 2>&1 &"
        
        MESSAGE(  "SALOME_ContainerPy_i::start_impl " + "os.system(" + str(shstr) + ")" )
        os.system( shstr )
        count = 21
        while container is None :
            time.sleep(1)
            count = count - 1
            MESSAGE(  str(count) + ". Waiting for " + str(theContainer) )
            try :
                obj = self._naming_service.Resolve(theContainer)
            except :
                obj = None
            if obj is None:
                container = None
            else:
                container = obj._narrow(Engines.Container)
                if container is None:
                    MESSAGE(  str(containerName) + ".object exists but is not a Container" )
                return container
            if count == 0 :
                return container

    #-------------------------------------------------------------------------

    def instance(self, nameToRegister, componentName):
        MESSAGE(  "SALOME_ContainerPy_i::instance " + str(nameToRegister) + ' ' + str(componentName) )
        self._numInstance = self._numInstance +1
        instanceName = nameToRegister + "_inst_" + `self._numInstance`

        component=__import__(componentName)
        factory=getattr(component,componentName)
        comp_i=factory(self._orb, self._poa, self._this(), self._containerName,
                       instanceName, nameToRegister)

        MESSAGE( "SALOME_ContainerPy_i::instance : component created")
        comp_o = comp_i._this()
        return comp_o

    #-------------------------------------------------------------------------

    def load_impl(self, nameToRegister, componentName):
        MESSAGE(  "SALOME_ContainerPy_i::load_impl " + str(nameToRegister) + ' ' + str(componentName) )
        self._numInstance = self._numInstance +1
        instanceName = nameToRegister + "_inst_" + `self._numInstance`
        interfaceName = nameToRegister
        the_command = "import " + nameToRegister + "\n"
        the_command = the_command + "comp_i = " + nameToRegister + "." + nameToRegister
        the_command = the_command + "(self._orb, self._poa, self._this(), self._containerName, instanceName, interfaceName)\n"
        MESSAGE( "SALOME_ContainerPy_i::load_impl :" + str (the_command) )
        exec the_command
        comp_o = comp_i._this()
        return comp_o
    
    #-------------------------------------------------------------------------
    
    def import_component(self, componentName):
        MESSAGE( "SALOME_Container_i::import_component" )
        reason = ""
        try:
            if verbose(): print "try import %s" % componentName
            # try import component
            module=__import__(componentName)
            if verbose(): print "import %s is done successfully" % componentName
            # if import successfully, check that component is loadable
            if not hasattr(module, componentName):
                reason = "module %s is not loadable" % componentName
                print reason
                pass
            pass
        except:
            import traceback
            print "cannot import %s" % componentName
            traceback.print_exc()
            reason = "cannot import %s" % componentName
        return reason

    #-------------------------------------------------------------------------

    def load_component_Library(self, componentName):
        MESSAGE(  "SALOME_ContainerPy_i::load_component_Library " + str(componentName) )
        ret = 0
        instanceName = componentName + "_inst_" + `self._numInstance`
        interfaceName = componentName
        reason = self.import_component(componentName)
        return reason == "", reason
    
    #-------------------------------------------------------------------------

    def create_component_instance_env(self, componentName, studyId, env):
      return self.create_component_instance(componentName, studyId), ""

    def create_component_instance(self, componentName, studyId):
        MESSAGE( "SALOME_ContainerPy_i::create_component_instance ==> " + str(componentName) + ' ' + str(studyId) )
        if studyId < 0:
            MESSAGE( "Study ID is lower than 0!" )
            return None
        else:
            self._numInstance = self._numInstance +1
            instanceName = componentName + "_inst_" + `self._numInstance`
            comp_iors=""
            try:
                component=__import__(componentName)
                factory=getattr(component,componentName)
                comp_i=factory(self._orb,
                               self._poa,
                               self._this(),
                               self._containerName,
                               instanceName,
                               componentName)
                
                MESSAGE( "SALOME_Container_i::create_component_instance : OK")
                comp_o = comp_i._this()
                self._listInstances_map[instanceName] = comp_i
            except:
                import traceback
                traceback.print_exc()
                MESSAGE( "SALOME_Container_i::create_component_instance : NOT OK")
            return comp_o

    #-------------------------------------------------------------------------

    def find_component_instance(self, registeredName, studyId):
        anEngine = None
        keysList = self._listInstances_map.keys()
        i = 0
        while i < len(keysList):
            instance = keysList[i]
            if find(instance,registeredName) == 0:
                anEngine = self._listInstances_map[instance]
                if studyId == anEngine.getStudyId():
                    return anEngine._this()
            i = i + 1
        return anEngine._this()
        
        
    #-------------------------------------------------------------------------

    def remove_impl(self, component):
        MESSAGE( "SALOME_ContainerPy_i::remove_impl" )
        instanceName = component._get_instanceName()
        MESSAGE( "unload component " + str(instanceName) )
        self._listInstances_map.remove(instanceName)
        component.destroy()
        self._naming_service.Destroy_Name(str(instanceName))

    #-------------------------------------------------------------------------

    def finalize_removal(self):
        MESSAGE( "SALOME_ContainerPy_i::finalize_removal" )
        return None

    #-------------------------------------------------------------------------

    def ping(self):
        MESSAGE( "SALOME_ContainerPy_i::ping() pid " + str(os.getpid()) )
        return None

    #-------------------------------------------------------------------------

    def getPID(self):
        return os.getpid()

    #-------------------------------------------------------------------------

    def _get_name(self):
        MESSAGE( "SALOME_ContainerPy_i::_get_name" )
        return self._containerName

    #-------------------------------------------------------------------------

    def getHostName(self):
        MESSAGE( "SALOME_ContainerPy_i::_get_MachineName" )
        self._machineName = "localhost"
        return self._machineName

    #-------------------------------------------------------------------------
    
    def _get_machineName(self):
        MESSAGE( "SALOME_ContainerPy_i::_get_MachineName" )
        self._machineName = "localhost"
        return self._machineName

    #-------------------------------------------------------------------------

    def Shutdown(self):
        self._naming_service.Destroy_Name(self._containerName);
        self._naming_service.Destroy_FullDirectory(self._containerName);
        self._orb.shutdown(0)
        pass

    def _get_logfilename(self):
      return self._logfilename
    def _set_logfilename(self,logfilename):
      self._logfilename=logfilename
    def _get_workingdir(self):
      return os.getcwd()

#=============================================================================

if __name__ == "__main__":
  # change the stdout buffering to line buffering (same as C++ cout buffering)
  sys.stdout=os.fdopen(1,"w",1)
  #initialise the ORB and find the root POA
  if verbose():print "Starting ",sys.argv[1]
  orb = CORBA.ORB_init(sys.argv, CORBA.ORB_ID)
  poa = orb.resolve_initial_references("RootPOA")
  if verbose():print "ORB and POA initialized"

  #create an instance of SALOME_ContainerPy_i and a Container reference
  #containerName = "FactoryServerPy"
  MESSAGE( str(sys.argv) )
  containerName = sys.argv[1]
  cpy_i = SALOME_ContainerPy_i(orb, poa, containerName)
  if verbose():print "SALOME_ContainerPy_i instance created ",cpy_i 
  cpy_o = cpy_i._this()
  if verbose():print "SALOME_ContainerPy_i instance activated ",cpy_o
  sys.stdout.flush()
  sys.stderr.flush()

  #activate the POA
  poaManager = poa._get_the_POAManager()
  poaManager.activate()

  #Block for ever
  orb.run()
  if verbose():print "SALOME_ContainerPy_i shutdown"



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

import batchmode_salome
import SALOME_ModuleCatalog

print
print "======================================================================"
print "           XML Catalog file generation from idl file"
print "======================================================================"

import os
os.system('runIDLparser -Wbcatalog=x \
                 ${KERNEL_ROOT_DIR}/idl/salome/SALOME_TestModuleCatalog.idl')

print "======================================================================"
print "           Get Catalog "
print "======================================================================"
obj = batchmode_salome.naming_service.Resolve('Kernel/ModulCatalog')
catalog = obj._narrow(SALOME_ModuleCatalog.ModuleCatalog)
catalog.GetComponentList()

print 
print "======================================================================"
print "           Import xml file "
print "======================================================================"
catalog.ImportXmlCatalogFile("x.xml")

name = "AddComponent"
print 
print "======================================================================"
print "           Dump component <", name, "> "
print "======================================================================"
C = catalog.GetComponent(name)

print "name       : ", C._get_componentname()
print "username   : ", C._get_componentusername()
print "type       : ", C._get_component_type()
print "constraint : ", C._get_constraint()
print "icon       : ", C._get_component_icone()

for iL in C.GetInterfaceList():
    I = C.GetInterface(iL)
    print "interface  : ", I.interfacename
    for S in I.interfaceservicelist:
        print "  service : ", S.ServiceName
        print "    ", len(S.ServiceinParameter), "in params : "
        for iP in S.ServiceinParameter:
            print '      ' + iP.Parametername + '(' + iP.Parametertype + ')'
            pass
        print "    ", len(S.ServiceoutParameter), "out params : "
        for iP in S.ServiceoutParameter:
            print '      ' + iP.Parametername + '(' + iP.Parametertype + ')'
            pass
        print "    ", len(S.ServiceinDataStreamParameter), "in datastream params : "
        for iP in S.ServiceinDataStreamParameter:
            print '      ' + iP.Parametername + '(' + str(iP.Parametertype) + ', ' + \
                  str(iP.Parameterdependency) + ')'
            pass
        print "    ", len(S.ServiceoutDataStreamParameter), "out datastream params : "
        for iP in S.ServiceoutDataStreamParameter:
            print '      ' + iP.Parametername + '(' + str(iP.Parametertype) + ', ' + \
                  str(iP.Parameterdependency) + ')'
            pass
        pass
    pass




#! /usr/bin/env python
#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  SALOME Container : implementation of container and engine for Kernel
#  File   : SALOME_ComponentPy.py
#  Author : Paul RASCLE, EDF
#  Module : SALOME
#  $Header: /home/server/cvs/KERNEL/KERNEL_SRC/src/Container/SALOME_ComponentPy.py,v 1.11.2.5.14.4.12.1 2012-04-12 14:05:03 vsr Exp $

## @package SALOME_ComponentPy
# \brief python implementation of component interface for Kernel
#

import os
import sys
import time
import string
import signal
from omniORB import CORBA, PortableServer, any
import Engines, Engines__POA
import Registry
from Utils_Identity import *
from SALOME_NamingServicePy import *
from libNOTIFICATION import *

from SALOME_utilities import *

from thread import *

#=============================================================================

_Sleeping = 0

## define an implementation of the component interface Engines::Component
#
#  
class SALOME_ComponentPy_i (Engines__POA.EngineComponent):
    _orb = None
    _poa = None
    _fieldsDict = []
    _studyId = -1
    
    #-------------------------------------------------------------------------

    def __init__ (self, orb, poa, contID, containerName,
                  instanceName, interfaceName, notif=0):
        # Notif for notification services
        # NOT YET IMPLEMENTED
        MESSAGE(  "SALOME_ComponentPy_i::__init__" + " " + str (containerName) + " " + str(instanceName) + " " + str(interfaceName) )
        self._orb = orb
        self._poa = poa
        self._instanceName = instanceName
        self._interfaceName = interfaceName
        self._containerName = containerName
        self._notif = notif
        self._myConnexionToRegistry = 0
        self._graphName = ''
        self._nodeName = ''
        self._serviceName = ''
        self._ThreadId = 0
        self._StartUsed = 0
        self._ThreadCpuUsed = 0
        self._Executed = 0
        self._contId = contID

        naming_service = SALOME_NamingServicePy_i(self._orb)
        myMachine=getShortHostName()
        Component_path = self._containerName + "/" + self._instanceName
        MESSAGE(  'SALOME_ComponentPy_i Register' + str( Component_path ) )
        id_o = poa.activate_object(self)
        compo_o = poa.id_to_reference(id_o)
        naming_service.Register(compo_o, Component_path)

        # Add componentinstance to registry
        obj = naming_service.Resolve('/Registry')
        if obj is None:
            MESSAGE(  "Registry Reference is invalid" )
        else:
            regist = obj._narrow(Registry.Components)
            if regist is None:
                MESSAGE(  "Registry Reference is invalid" )
            else:
                ior = orb.object_to_string(contID)
                MESSAGE(  ior )

                lesInfos = Identity(self._instanceName)
                infos = Registry.Infos(lesInfos._name,
                                       lesInfos._pid,
                                       lesInfos._machine,
                                       lesInfos._adip,
                                       lesInfos._uid,
                                       lesInfos._pwname,
                                       int(lesInfos._tc_start),
                                       0,0,0,
                                       lesInfos._cdir,
                                       -1,
                                       ior)

                res = regist.add(infos)

        self._notifSupplier = NOTIFICATION_Supplier_Swig(instanceName, notif)

    #-------------------------------------------------------------------------

    def _get_instanceName(self):
        MESSAGE(  "SALOME_ComponentPy_i::_get_instanceName" )
        return self._instanceName
    
    #-------------------------------------------------------------------------

    def _get_interfaceName(self):
        MESSAGE(  "SALOME_ComponentPy_i::_get_interfaceName" )
        return self._interfaceName

    #-------------------------------------------------------------------------

    def ping(self):
        MESSAGE(  "SALOME_ComponentPy_i::ping() pid " + str(os.getpid()) )
        
    #-------------------------------------------------------------------------

    def setProperties(self, dico):
        self._fieldsDict = dico
    
    #-------------------------------------------------------------------------

    def getProperties(self):
        return self._fieldsDict

    #-------------------------------------------------------------------------

    def destroy(self):
        MESSAGE(  "SALOME_ComponentPy_i::destroy" )
        id = self._poa.servant_to_id(self)
        self._poa.deactivate_object(id)
        return
        
    #-------------------------------------------------------------------------

    def GetContainerRef(self):
        MESSAGE(  "SALOME_ComponentPy_i::GetContainerRef" )
        return self._contId._narrow(Engines.Container)
                
    #-------------------------------------------------------------------------

    def beginService(self , serviceName ):
        MESSAGE(  "Send BeginService notification for " + str(serviceName) + " for graph/node " + str(self._graphName) + " " + str(self._nodeName) )
        MESSAGE(  "Component instance : " + str ( self._instanceName ) )
        self._serviceName = str(serviceName)
        self._ThreadId = get_ident()
        self._StartUsed = 0
        self._StartUsed = self.CpuUsed_impl()
        self._ThreadCpuUsed = 0
        self._Executed = 1
        print "beginService for ",serviceName," Component instance : ",self._instanceName
        MESSAGE( "SALOME_ComponentPy_i::beginService _StartUsed " + str( self._ThreadId ) + " " + str( self._StartUsed ) )
        for e in self._fieldsDict:
          key=e.key
          value=any.from_any(e.value)
          if isinstance(value,str):
            os.environ[key]=value
        

    #-------------------------------------------------------------------------

    def endService(self , serviceName ):
        MESSAGE(  "Send EndService notification for " + str( self._ThreadId ) + " " + str(serviceName) + " for graph/node " + str(self._graphName) + " " + str(self._nodeName) + " CpuUsed " + str( self.CpuUsed_impl() ) )
        MESSAGE(  "Component instance : " + str(self._instanceName) )
        print "endService for",serviceName,"Component instance :",self._instanceName,"Cpu Used:",self.CpuUsed_impl()," (s) "


    #-------------------------------------------------------------------------

    def sendMessage(self , event_type , message ):
        self._notifSupplier.Send(self.graphName(), self.nodeName(), event_type, message)

    #-------------------------------------------------------------------------

    def Names(self , GraphName , NodeName ):
        MESSAGE(  "SALOME_ComponentPy_i::Names" + str(GraphName) + str(NodeName) )
        self._graphName = GraphName
        self._nodeName = NodeName
        
    #-------------------------------------------------------------------------

    def graphName(self):
        return self._graphName

    #-------------------------------------------------------------------------

    def nodeName(self):
        return self._nodeName

    #-------------------------------------------------------------------------

    def Killer(self, ThreadId, signum):
        #if ThreadId > 0:
            #if signum == 0:
                #if pthread_cancel(ThreadId): <- from C++
                #   return 0
                #else:
                #   MESSAGE()
            #else:
                #if pthread_kill(ThreadId): <- from C++
                #   return 0
                #else:
                #   MESSAGE()
        return 1                 
    
    #-------------------------------------------------------------------------

    def Kill_impl(self):
        MESSAGE(  "SALOME_ComponentPy_i::Kill_impl" )
        RetVal = 0
        if self._ThreadId > 0 & self._ThreadId != get_ident():
            RetVal = Killer(self._ThreadId,0)
            self._ThreadId = 0
        return RetVal

    #-------------------------------------------------------------------------

    def Stop_impl(self):
        MESSAGE(  "SALOME_ComponentPy_i::Stop_impl" )
        RetVal = 0
        if self._ThreadId > 0 & self._ThreadId != get_ident():
            RetVal = Killer(self._ThreadId,0)
            self._ThreadId = 0
        return RetVal

    #-------------------------------------------------------------------------

    def Suspend_impl(self):
        MESSAGE(  "SALOME_ComponentPy_i::Suspend_impl" )
        global _Sleeping
        RetVal = 0
        if self._ThreadId > 0 & self._ThreadId != get_ident():
            if _Sleeping > 0:
                return 0
            else:
                RetVal = Killer(self._ThreadId, signal.SIGINT)
                if RetVal > 0:
                    _Sleeping = 1
        return RetVal

    #-------------------------------------------------------------------------

    def Resume_impl(self):
        MESSAGE(  "SALOME_ComponentPy_i::Resume_impl" )
        global _Sleeping
        RetVal = 0
        if self._ThreadId > 0 & self._ThreadId != get_ident():
            if _Sleeping > 0:
                _Sleeping = 0
                RetVal = 1
            else:
                RetVal = 0
        return RetVal

    #-------------------------------------------------------------------------

    def CpuUsed_impl(self):
        if ( self._ThreadId | self._Executed ) :
            if self._ThreadId == get_ident() :
                cpu = time.clock()
                self._ThreadCpuUsed = cpu - self._StartUsed
                MESSAGE( "SALOME_ComponentPy_i::CpuUsed_impl " + self._serviceName + " " + str( int(cpu) ) + " - " + str( self._StartUsed ) + " = " + str( self._ThreadCpuUsed ) )
                return self._ThreadCpuUsed
            MESSAGE( "SALOME_ComponentPy_i::CpuUsed_impl " + self._serviceName + " " + str( self._ThreadCpuUsed ) )
            return self._ThreadCpuUsed
        MESSAGE( "SALOME_ComponentPy_i::CpuUsed_impl self._StartUsed " + self._serviceName + " " + str(self._StartUsed) )
        return 0

    #-------------------------------------------------------------------------
   
    def DumpPython(self, theStudy, isPublished, isMultiFile):
        aBuffer = "\0"
        if isMultiFile :
            aBuffer = "def RebuildData(theStudy): pass\n\0"
        return (aBuffer, 1)

    #-------------------------------------------------------------------------    

    def getStudyId(self):
        return self._studyId

    #-------------------------------------------------------------------------    

    def hasObjectInfo(self):
        return 0

    #-------------------------------------------------------------------------    

    def getObjectInfo(self, studyId, entry):
        return ""




#!/usr/bin/env python
#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

## \file waitContainers.py
# \brief command to wait until containers are launched
#
# the container names (in naming service) are passed on the command line as in :
# waitContainers.py FactoryServer

import sys
import time
import orbmodule
import CosNaming
clt = orbmodule.client()
clt.waitNS("/ContainerManager")
obj = clt.orb.resolve_initial_references("NameService")
rootContext = obj._narrow(CosNaming.NamingContext)
cname = []
cname.append(CosNaming.NameComponent('Containers', 'dir'))

while(1):
  try:
    ccontext = rootContext.resolve(cname)
    break
  except CosNaming.NamingContext.NotFound, ex:
    time.sleep(1)
  except CosNaming.NamingContext.InvalidName, ex:
    time.sleep(1)
  except CosNaming.NamingContext.CannotProceed, ex:
    time.sleep(1)
  except (CORBA.TRANSIENT,CORBA.OBJECT_NOT_EXIST,CORBA.COMM_FAILURE):
    time.sleep(1)

def waitContainer(mycont):
  while(1):
    bl,bi=ccontext.list(0)
    if bi is not None:
      ok,b=bi.next_one()
      while(ok):
        for s in b.binding_name :
          if s.kind == "dir":
            obj=ccontext.resolve([s])
            scontext = obj._narrow(CosNaming.NamingContext)
            bll,bii=scontext.list(0)
            if bii is not None:
              ok,bb=bii.next_one()
              while(ok):
                for s in bb.binding_name :
                   if s.id == mycont:
                     print s.id
                     return
                ok,bb=bii.next_one()
        ok,b=bi.next_one()
    sys.stdout.write('+')
    sys.stdout.flush()
    time.sleep(1)

for cont in sys.argv:
  if cont != sys.argv[0]:
    waitContainer(cont)

